# octopus-deploy-swagger-client
Octopus Deploy API client in Python (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2019.6.7+Branch.tags-2019.6.7.Sha.aa18dc6809953218c66f57eff7d26481d9b23d6a
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.PythonClientCodegen

Modified APIs and Models to support Variable update, Machine info load and Environment APIs.

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import octopus_deploy_swagger_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import octopus_deploy_swagger_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import octopus_deploy_swagger_client
from octopus_deploy_swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: APIKeyHeader
configuration = octopus_deploy_swagger_client.Configuration()
configuration.api_key['X-Octopus-ApiKey'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-Octopus-ApiKey'] = 'Bearer'
# Configure API key authorization: APIKeyQuery
configuration = octopus_deploy_swagger_client.Configuration()
configuration.api_key['ApiKey'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['ApiKey'] = 'Bearer'
# Configure API key authorization: NugetApiKeyHeader
configuration = octopus_deploy_swagger_client.Configuration()
configuration.api_key['X-NuGet-ApiKey'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-NuGet-ApiKey'] = 'Bearer'

# create an instance of the API class
api_instance = octopus_deploy_swagger_client.AccountsApi(octopus_deploy_swagger_client.ApiClient(configuration))
account_resource = octopus_deploy_swagger_client.AccountResource() # AccountResource | The AccountResource resource to create (optional)

try:
    # Create a AccountResource
    api_response = api_instance.create_response_descriptor_environments_accounts_account_accounts_account_resource(account_resource=account_resource)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AccountsApi->create_response_descriptor_environments_accounts_account_accounts_account_resource: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountsApi* | [**create_response_descriptor_environments_accounts_account_accounts_account_resource**](docs/AccountsApi.md#create_response_descriptor_environments_accounts_account_accounts_account_resource) | **POST** /api/accounts | Create a AccountResource
*AccountsApi* | [**create_response_descriptor_environments_accounts_account_accounts_account_resource_spaces**](docs/AccountsApi.md#create_response_descriptor_environments_accounts_account_accounts_account_resource_spaces) | **POST** /api/{baseSpaceId}/accounts | Create a AccountResource
*AccountsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_account_public_key_download_action**](docs/AccountsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_account_public_key_download_action) | **GET** /api/accounts/{id}/pk | 
*AccountsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_account_public_key_download_action_spaces**](docs/AccountsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_account_public_key_download_action_spaces) | **GET** /api/{baseSpaceId}/accounts/{id}/pk | 
*AccountsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_account_usage_list_action**](docs/AccountsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_account_usage_list_action) | **GET** /api/accounts/{id}/usages | 
*AccountsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_account_usage_list_action_spaces**](docs/AccountsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_account_usage_list_action_spaces) | **GET** /api/{baseSpaceId}/accounts/{id}/usages | 
*AccountsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_azure_environments_list_action**](docs/AccountsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_azure_environments_list_action) | **GET** /api/accounts/azureenvironments | 
*AccountsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_azure_environments_list_action_spaces**](docs/AccountsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_azure_environments_list_action_spaces) | **GET** /api/{baseSpaceId}/accounts/azureenvironments | 
*AccountsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_azure_resource_groups_list_action**](docs/AccountsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_azure_resource_groups_list_action) | **GET** /api/accounts/{id}/resourceGroups | 
*AccountsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_azure_resource_groups_list_action_spaces**](docs/AccountsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_azure_resource_groups_list_action_spaces) | **GET** /api/{baseSpaceId}/accounts/{id}/resourceGroups | 
*AccountsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_azure_storage_accounts_list_action**](docs/AccountsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_azure_storage_accounts_list_action) | **GET** /api/accounts/{id}/storageAccounts | 
*AccountsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_azure_storage_accounts_list_action_spaces**](docs/AccountsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_azure_storage_accounts_list_action_spaces) | **GET** /api/{baseSpaceId}/accounts/{id}/storageAccounts | 
*AccountsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_azure_web_sites_list_action**](docs/AccountsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_azure_web_sites_list_action) | **GET** /api/accounts/{id}/websites | 
*AccountsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_azure_web_sites_list_action_spaces**](docs/AccountsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_azure_web_sites_list_action_spaces) | **GET** /api/{baseSpaceId}/accounts/{id}/websites | 
*AccountsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_azure_web_sites_slot_list_action**](docs/AccountsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_azure_web_sites_slot_list_action) | **GET** /api/accounts/{id}/{resourceGroupName}/websites/{webSiteName}/slots | 
*AccountsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_azure_web_sites_slot_list_action_spaces**](docs/AccountsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_azure_web_sites_slot_list_action_spaces) | **GET** /api/{baseSpaceId}/accounts/{id}/{resourceGroupName}/websites/{webSiteName}/slots | 
*AccountsApi* | [**delete_on_background_response_descriptor_environments_accounts_account_accounts_account_resource**](docs/AccountsApi.md#delete_on_background_response_descriptor_environments_accounts_account_accounts_account_resource) | **DELETE** /api/accounts/{id} | Delete a AccountResource by ID
*AccountsApi* | [**delete_on_background_response_descriptor_environments_accounts_account_accounts_account_resource_spaces**](docs/AccountsApi.md#delete_on_background_response_descriptor_environments_accounts_account_accounts_account_resource_spaces) | **DELETE** /api/{baseSpaceId}/accounts/{id} | Delete a AccountResource by ID
*AccountsApi* | [**index_response_descriptor_environments_accounts_account_accounts_account_resource**](docs/AccountsApi.md#index_response_descriptor_environments_accounts_account_accounts_account_resource) | **GET** /api/accounts | Get a list of AccountResources
*AccountsApi* | [**index_response_descriptor_environments_accounts_account_accounts_account_resource_spaces**](docs/AccountsApi.md#index_response_descriptor_environments_accounts_account_accounts_account_resource_spaces) | **GET** /api/{baseSpaceId}/accounts | Get a list of AccountResources
*AccountsApi* | [**list_all_response_descriptor_environments_accounts_account_accounts_account_resource**](docs/AccountsApi.md#list_all_response_descriptor_environments_accounts_account_accounts_account_resource) | **GET** /api/accounts/all | Get a list of AccountResources
*AccountsApi* | [**list_all_response_descriptor_environments_accounts_account_accounts_account_resource_spaces**](docs/AccountsApi.md#list_all_response_descriptor_environments_accounts_account_accounts_account_resource_spaces) | **GET** /api/{baseSpaceId}/accounts/all | Get a list of AccountResources
*AccountsApi* | [**load_response_descriptor_environments_accounts_account_accounts_account_resource**](docs/AccountsApi.md#load_response_descriptor_environments_accounts_account_accounts_account_resource) | **GET** /api/accounts/{id} | Get a AccountResource by ID
*AccountsApi* | [**load_response_descriptor_environments_accounts_account_accounts_account_resource_spaces**](docs/AccountsApi.md#load_response_descriptor_environments_accounts_account_accounts_account_resource_spaces) | **GET** /api/{baseSpaceId}/accounts/{id} | Get a AccountResource by ID
*AccountsApi* | [**modify_response_descriptor_environments_accounts_account_accounts_account_resource**](docs/AccountsApi.md#modify_response_descriptor_environments_accounts_account_accounts_account_resource) | **PUT** /api/accounts/{id} | Modify a AccountResource by ID
*AccountsApi* | [**modify_response_descriptor_environments_accounts_account_accounts_account_resource_spaces**](docs/AccountsApi.md#modify_response_descriptor_environments_accounts_account_accounts_account_resource_spaces) | **PUT** /api/{baseSpaceId}/accounts/{id} | Modify a AccountResource by ID
*ActionTemplatesApi* | [**create_response_descriptor_projects_action_template_action_template_resource**](docs/ActionTemplatesApi.md#create_response_descriptor_projects_action_template_action_template_resource) | **POST** /api/actiontemplates | Create a ActionTemplateResource
*ActionTemplatesApi* | [**create_response_descriptor_projects_action_template_action_template_resource_spaces**](docs/ActionTemplatesApi.md#create_response_descriptor_projects_action_template_action_template_resource_spaces) | **POST** /api/{baseSpaceId}/actiontemplates | Create a ActionTemplateResource
*ActionTemplatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_action_template_logo_get_responder**](docs/ActionTemplatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_action_template_logo_get_responder) | **GET** /api/actiontemplates/{typeOrId}/logo | 
*ActionTemplatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_action_template_logo_get_responder_0**](docs/ActionTemplatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_action_template_logo_get_responder_0) | **GET** /api/actiontemplates/{typeOrId}/versions/{version}/logo | 
*ActionTemplatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_action_template_logo_get_responder_spaces**](docs/ActionTemplatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_action_template_logo_get_responder_spaces) | **GET** /api/{baseSpaceId}/actiontemplates/{typeOrId}/logo | 
*ActionTemplatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_action_template_logo_get_responder_spaces_0**](docs/ActionTemplatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_action_template_logo_get_responder_spaces_0) | **GET** /api/{baseSpaceId}/actiontemplates/{typeOrId}/versions/{version}/logo | 
*ActionTemplatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_action_template_logo_put_responder**](docs/ActionTemplatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_action_template_logo_put_responder) | **PUT** /api/actiontemplates/{id}/logo | 
*ActionTemplatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_action_template_logo_put_responder_0**](docs/ActionTemplatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_action_template_logo_put_responder_0) | **POST** /api/actiontemplates/{id}/logo | 
*ActionTemplatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_action_template_logo_put_responder_spaces**](docs/ActionTemplatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_action_template_logo_put_responder_spaces) | **PUT** /api/{baseSpaceId}/actiontemplates/{id}/logo | 
*ActionTemplatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_action_template_logo_put_responder_spaces_0**](docs/ActionTemplatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_action_template_logo_put_responder_spaces_0) | **POST** /api/{baseSpaceId}/actiontemplates/{id}/logo | 
*ActionTemplatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_action_template_usage_responder**](docs/ActionTemplatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_action_template_usage_responder) | **GET** /api/actiontemplates/{id}/usage | 
*ActionTemplatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_action_template_usage_responder_spaces**](docs/ActionTemplatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_action_template_usage_responder_spaces) | **GET** /api/{baseSpaceId}/actiontemplates/{id}/usage | 
*ActionTemplatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_action_template_version_get_responder**](docs/ActionTemplatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_action_template_version_get_responder) | **GET** /api/actiontemplates/{id}/versions/{version?} | 
*ActionTemplatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_action_template_version_get_responder_spaces**](docs/ActionTemplatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_action_template_version_get_responder_spaces) | **GET** /api/{baseSpaceId}/actiontemplates/{id}/versions/{version?} | 
*ActionTemplatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_action_templates_search_responder**](docs/ActionTemplatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_action_templates_search_responder) | **GET** /api/actiontemplates/search | 
*ActionTemplatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_action_templates_search_responder_spaces**](docs/ActionTemplatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_action_templates_search_responder_spaces) | **GET** /api/{baseSpaceId}/actiontemplates/search | 
*ActionTemplatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_deployment_action_update_action_template_actions_update_responder**](docs/ActionTemplatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_deployment_action_update_action_template_actions_update_responder) | **POST** /api/actiontemplates/{id}/actionsUpdate | 
*ActionTemplatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_deployment_action_update_action_template_actions_update_responder_spaces**](docs/ActionTemplatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_deployment_action_update_action_template_actions_update_responder_spaces) | **POST** /api/{baseSpaceId}/actiontemplates/{id}/actionsUpdate | 
*ActionTemplatesApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_action_template_categories_responder**](docs/ActionTemplatesApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_action_template_categories_responder) | **GET** /api/actiontemplates/categories | 
*ActionTemplatesApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_action_template_categories_responder_spaces**](docs/ActionTemplatesApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_action_template_categories_responder_spaces) | **GET** /api/{baseSpaceId}/actiontemplates/categories | 
*ActionTemplatesApi* | [**delete_on_background_response_descriptor_projects_action_template_action_template_resource**](docs/ActionTemplatesApi.md#delete_on_background_response_descriptor_projects_action_template_action_template_resource) | **DELETE** /api/actiontemplates/{id} | Delete a ActionTemplateResource by ID
*ActionTemplatesApi* | [**delete_on_background_response_descriptor_projects_action_template_action_template_resource_spaces**](docs/ActionTemplatesApi.md#delete_on_background_response_descriptor_projects_action_template_action_template_resource_spaces) | **DELETE** /api/{baseSpaceId}/actiontemplates/{id} | Delete a ActionTemplateResource by ID
*ActionTemplatesApi* | [**index_response_descriptor_projects_action_template_action_template_resource**](docs/ActionTemplatesApi.md#index_response_descriptor_projects_action_template_action_template_resource) | **GET** /api/actiontemplates | Get a list of ActionTemplateResources
*ActionTemplatesApi* | [**index_response_descriptor_projects_action_template_action_template_resource_spaces**](docs/ActionTemplatesApi.md#index_response_descriptor_projects_action_template_action_template_resource_spaces) | **GET** /api/{baseSpaceId}/actiontemplates | Get a list of ActionTemplateResources
*ActionTemplatesApi* | [**list_all_response_descriptor_projects_action_template_action_template_resource**](docs/ActionTemplatesApi.md#list_all_response_descriptor_projects_action_template_action_template_resource) | **GET** /api/actiontemplates/all | Get a list of ActionTemplateResources
*ActionTemplatesApi* | [**list_all_response_descriptor_projects_action_template_action_template_resource_spaces**](docs/ActionTemplatesApi.md#list_all_response_descriptor_projects_action_template_action_template_resource_spaces) | **GET** /api/{baseSpaceId}/actiontemplates/all | Get a list of ActionTemplateResources
*ActionTemplatesApi* | [**load_response_descriptor_projects_action_template_action_template_resource**](docs/ActionTemplatesApi.md#load_response_descriptor_projects_action_template_action_template_resource) | **GET** /api/actiontemplates/{id} | Get a ActionTemplateResource by ID
*ActionTemplatesApi* | [**load_response_descriptor_projects_action_template_action_template_resource_spaces**](docs/ActionTemplatesApi.md#load_response_descriptor_projects_action_template_action_template_resource_spaces) | **GET** /api/{baseSpaceId}/actiontemplates/{id} | Get a ActionTemplateResource by ID
*ActionTemplatesApi* | [**modify_response_descriptor_projects_action_template_action_template_resource**](docs/ActionTemplatesApi.md#modify_response_descriptor_projects_action_template_action_template_resource) | **PUT** /api/actiontemplates/{id} | Modify a ActionTemplateResource by ID
*ActionTemplatesApi* | [**modify_response_descriptor_projects_action_template_action_template_resource_spaces**](docs/ActionTemplatesApi.md#modify_response_descriptor_projects_action_template_action_template_resource_spaces) | **PUT** /api/{baseSpaceId}/actiontemplates/{id} | Modify a ActionTemplateResource by ID
*ApiKeysApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_create_api_key_action**](docs/ApiKeysApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_create_api_key_action) | **POST** /api/users/{userId}/apikeys | 
*ApiKeysApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_index_api_keys_responder**](docs/ApiKeysApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_index_api_keys_responder) | **GET** /api/users/{userId}/apikeys | 
*ApiKeysApi* | [**delete_on_background_response_descriptor_users_api_key_api_key_resource**](docs/ApiKeysApi.md#delete_on_background_response_descriptor_users_api_key_api_key_resource) | **DELETE** /api/users/{userId}/apikeys/{id} | Delete a ApiKeyResource by ID
*ApiKeysApi* | [**load_response_descriptor_users_api_key_api_key_resource**](docs/ApiKeysApi.md#load_response_descriptor_users_api_key_api_key_resource) | **GET** /api/users/{userId}/apikeys/{id} | Get a ApiKeyResource by ID
*ArtifactsApi* | [**create_response_descriptor_server_tasks_artifact_artifact_resource**](docs/ArtifactsApi.md#create_response_descriptor_server_tasks_artifact_artifact_resource) | **POST** /api/artifacts | Create a ArtifactResource
*ArtifactsApi* | [**create_response_descriptor_server_tasks_artifact_artifact_resource_spaces**](docs/ArtifactsApi.md#create_response_descriptor_server_tasks_artifact_artifact_resource_spaces) | **POST** /api/{baseSpaceId}/artifacts | Create a ArtifactResource
*ArtifactsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_artifacts_responder**](docs/ArtifactsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_artifacts_responder) | **GET** /api/artifacts | 
*ArtifactsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_artifacts_responder_spaces**](docs/ArtifactsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_artifacts_responder_spaces) | **GET** /api/{baseSpaceId}/artifacts | 
*ArtifactsApi* | [**delete_on_background_response_descriptor_server_tasks_artifact_artifact_resource**](docs/ArtifactsApi.md#delete_on_background_response_descriptor_server_tasks_artifact_artifact_resource) | **DELETE** /api/artifacts/{id} | Delete a ArtifactResource by ID
*ArtifactsApi* | [**delete_on_background_response_descriptor_server_tasks_artifact_artifact_resource_spaces**](docs/ArtifactsApi.md#delete_on_background_response_descriptor_server_tasks_artifact_artifact_resource_spaces) | **DELETE** /api/{baseSpaceId}/artifacts/{id} | Delete a ArtifactResource by ID
*ArtifactsApi* | [**file_response_descriptor_octopus_server_web_api_actions_artifact_content_action**](docs/ArtifactsApi.md#file_response_descriptor_octopus_server_web_api_actions_artifact_content_action) | **GET** /api/artifacts/{id}/content | 
*ArtifactsApi* | [**file_response_descriptor_octopus_server_web_api_actions_artifact_content_action_0**](docs/ArtifactsApi.md#file_response_descriptor_octopus_server_web_api_actions_artifact_content_action_0) | **PUT** /api/artifacts/{id}/content | 
*ArtifactsApi* | [**file_response_descriptor_octopus_server_web_api_actions_artifact_content_action_spaces**](docs/ArtifactsApi.md#file_response_descriptor_octopus_server_web_api_actions_artifact_content_action_spaces) | **GET** /api/{baseSpaceId}/artifacts/{id}/content | 
*ArtifactsApi* | [**file_response_descriptor_octopus_server_web_api_actions_artifact_content_action_spaces_0**](docs/ArtifactsApi.md#file_response_descriptor_octopus_server_web_api_actions_artifact_content_action_spaces_0) | **PUT** /api/{baseSpaceId}/artifacts/{id}/content | 
*ArtifactsApi* | [**load_response_descriptor_server_tasks_artifact_artifact_resource**](docs/ArtifactsApi.md#load_response_descriptor_server_tasks_artifact_artifact_resource) | **GET** /api/artifacts/{id} | Get a ArtifactResource by ID
*ArtifactsApi* | [**load_response_descriptor_server_tasks_artifact_artifact_resource_spaces**](docs/ArtifactsApi.md#load_response_descriptor_server_tasks_artifact_artifact_resource_spaces) | **GET** /api/{baseSpaceId}/artifacts/{id} | Get a ArtifactResource by ID
*ArtifactsApi* | [**modify_response_descriptor_server_tasks_artifact_artifact_resource**](docs/ArtifactsApi.md#modify_response_descriptor_server_tasks_artifact_artifact_resource) | **PUT** /api/artifacts/{id} | Modify a ArtifactResource by ID
*ArtifactsApi* | [**modify_response_descriptor_server_tasks_artifact_artifact_resource_spaces**](docs/ArtifactsApi.md#modify_response_descriptor_server_tasks_artifact_artifact_resource_spaces) | **PUT** /api/{baseSpaceId}/artifacts/{id} | Modify a ArtifactResource by ID
*AuthenticationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_authentication_authentication_responder**](docs/AuthenticationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_authentication_authentication_responder) | **GET** /api/authentication | 
*AuthenticationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_authentication_login_initiated_responder**](docs/AuthenticationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_authentication_login_initiated_responder) | **POST** /api/authentication/checklogininitiated | 
*CertificateConfigurationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_certificate_public_cer_download_action**](docs/CertificateConfigurationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_certificate_public_cer_download_action) | **GET** /api/configuration/certificates/{id}/public-cer | 
*CertificateConfigurationApi* | [**index_response_descriptor_configuration_certificate_configuration_certificate_configuration_resource**](docs/CertificateConfigurationApi.md#index_response_descriptor_configuration_certificate_configuration_certificate_configuration_resource) | **GET** /api/configuration/certificates | Get a list of CertificateConfigurationResources
*CertificateConfigurationApi* | [**load_response_descriptor_configuration_certificate_configuration_certificate_configuration_resource**](docs/CertificateConfigurationApi.md#load_response_descriptor_configuration_certificate_configuration_certificate_configuration_resource) | **GET** /api/certificates/(?&lt;id&gt;(?i)^(certificate-global)) | Get a CertificateConfigurationResource by ID
*CertificateConfigurationApi* | [**load_response_descriptor_configuration_certificate_configuration_certificate_configuration_resource_0**](docs/CertificateConfigurationApi.md#load_response_descriptor_configuration_certificate_configuration_certificate_configuration_resource_0) | **GET** /api/configuration/certificates/{id} | Get a CertificateConfigurationResource by ID
*CertificatesApi* | [**create_response_descriptor_certificate_certificate_resource**](docs/CertificatesApi.md#create_response_descriptor_certificate_certificate_resource) | **POST** /api/certificates | Create a CertificateResource
*CertificatesApi* | [**create_response_descriptor_certificate_certificate_resource_spaces**](docs/CertificatesApi.md#create_response_descriptor_certificate_certificate_resource_spaces) | **POST** /api/{baseSpaceId}/certificates | Create a CertificateResource
*CertificatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_certificates_certificate_archive_action**](docs/CertificatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_certificates_certificate_archive_action) | **POST** /api/certificates/{id}/archive | 
*CertificatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_certificates_certificate_archive_action_spaces**](docs/CertificatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_certificates_certificate_archive_action_spaces) | **POST** /api/{baseSpaceId}/certificates/{id}/archive | 
*CertificatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_certificates_certificate_export_action**](docs/CertificatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_certificates_certificate_export_action) | **GET** /api/certificates/{id}/export | 
*CertificatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_certificates_certificate_export_action_spaces**](docs/CertificatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_certificates_certificate_export_action_spaces) | **GET** /api/{baseSpaceId}/certificates/{id}/export | 
*CertificatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_certificates_certificate_replace_action**](docs/CertificatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_certificates_certificate_replace_action) | **POST** /api/certificates/{id}/replace | 
*CertificatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_certificates_certificate_replace_action_spaces**](docs/CertificatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_certificates_certificate_replace_action_spaces) | **POST** /api/{baseSpaceId}/certificates/{id}/replace | 
*CertificatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_certificates_certificate_un_archive_action**](docs/CertificatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_certificates_certificate_un_archive_action) | **POST** /api/certificates/{id}/unarchive | 
*CertificatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_certificates_certificate_un_archive_action_spaces**](docs/CertificatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_certificates_certificate_un_archive_action_spaces) | **POST** /api/{baseSpaceId}/certificates/{id}/unarchive | 
*CertificatesApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_certificates_certificate_by_id_or_thumbprint_responder**](docs/CertificatesApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_certificates_certificate_by_id_or_thumbprint_responder) | **GET** /api/certificates/(?&lt;idOrThumbprint&gt;(?i)^(?!(certificate-global)).*) | 
*CertificatesApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_certificates_certificate_by_id_or_thumbprint_responder_spaces**](docs/CertificatesApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_certificates_certificate_by_id_or_thumbprint_responder_spaces) | **GET** /api/{baseSpaceId}/certificates/(?&lt;idOrThumbprint&gt;(?i)^(?!(certificate-global)).*) | 
*CertificatesApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_certificates_certificate_usage_responder**](docs/CertificatesApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_certificates_certificate_usage_responder) | **GET** /api/certificates/{id}/usages | 
*CertificatesApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_certificates_certificate_usage_responder_spaces**](docs/CertificatesApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_certificates_certificate_usage_responder_spaces) | **GET** /api/{baseSpaceId}/certificates/{id}/usages | 
*CertificatesApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_certificates_certificates_list_responder**](docs/CertificatesApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_certificates_certificates_list_responder) | **GET** /api/certificates | 
*CertificatesApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_certificates_certificates_list_responder_spaces**](docs/CertificatesApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_certificates_certificates_list_responder_spaces) | **GET** /api/{baseSpaceId}/certificates | 
*CertificatesApi* | [**delete_on_background_response_descriptor_certificate_certificate_resource**](docs/CertificatesApi.md#delete_on_background_response_descriptor_certificate_certificate_resource) | **DELETE** /api/certificates/{id} | Delete a CertificateResource by ID
*CertificatesApi* | [**delete_on_background_response_descriptor_certificate_certificate_resource_spaces**](docs/CertificatesApi.md#delete_on_background_response_descriptor_certificate_certificate_resource_spaces) | **DELETE** /api/{baseSpaceId}/certificates/{id} | Delete a CertificateResource by ID
*CertificatesApi* | [**list_all_response_descriptor_certificate_certificate_resource**](docs/CertificatesApi.md#list_all_response_descriptor_certificate_certificate_resource) | **GET** /api/certificates/all | Get a list of CertificateResources
*CertificatesApi* | [**list_all_response_descriptor_certificate_certificate_resource_spaces**](docs/CertificatesApi.md#list_all_response_descriptor_certificate_certificate_resource_spaces) | **GET** /api/{baseSpaceId}/certificates/all | Get a list of CertificateResources
*CertificatesApi* | [**modify_response_descriptor_certificate_certificate_resource**](docs/CertificatesApi.md#modify_response_descriptor_certificate_certificate_resource) | **PUT** /api/certificates/{id} | Modify a CertificateResource by ID
*CertificatesApi* | [**modify_response_descriptor_certificate_certificate_resource_spaces**](docs/CertificatesApi.md#modify_response_descriptor_certificate_certificate_resource_spaces) | **PUT** /api/{baseSpaceId}/certificates/{id} | Modify a CertificateResource by ID
*ChannelsApi* | [**child_index_response_descriptor_projects_channel_projects_release_channel_resource_release_resource**](docs/ChannelsApi.md#child_index_response_descriptor_projects_channel_projects_release_channel_resource_release_resource) | **GET** /api/channels/{id}/releases | Get a list of ReleaseResources
*ChannelsApi* | [**child_index_response_descriptor_projects_channel_projects_release_channel_resource_release_resource_spaces**](docs/ChannelsApi.md#child_index_response_descriptor_projects_channel_projects_release_channel_resource_release_resource_spaces) | **GET** /api/{baseSpaceId}/channels/{id}/releases | Get a list of ReleaseResources
*ChannelsApi* | [**child_index_response_descriptor_projects_project_projects_channel_project_resource_channel_resource**](docs/ChannelsApi.md#child_index_response_descriptor_projects_project_projects_channel_project_resource_channel_resource) | **GET** /api/projects/{id}/channels | Get a list of ChannelResources
*ChannelsApi* | [**child_index_response_descriptor_projects_project_projects_channel_project_resource_channel_resource_spaces**](docs/ChannelsApi.md#child_index_response_descriptor_projects_project_projects_channel_project_resource_channel_resource_spaces) | **GET** /api/{baseSpaceId}/projects/{id}/channels | Get a list of ChannelResources
*ChannelsApi* | [**create_response_descriptor_projects_channel_channel_resource**](docs/ChannelsApi.md#create_response_descriptor_projects_channel_channel_resource) | **POST** /api/channels | Create a ChannelResource
*ChannelsApi* | [**create_response_descriptor_projects_channel_channel_resource_spaces**](docs/ChannelsApi.md#create_response_descriptor_projects_channel_channel_resource_spaces) | **POST** /api/{baseSpaceId}/channels | Create a ChannelResource
*ChannelsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_version_rule_test_action**](docs/ChannelsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_version_rule_test_action) | **GET** /api/channels/rule-test | 
*ChannelsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_version_rule_test_action_0**](docs/ChannelsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_version_rule_test_action_0) | **POST** /api/channels/rule-test | 
*ChannelsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_version_rule_test_action_spaces**](docs/ChannelsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_version_rule_test_action_spaces) | **GET** /api/{baseSpaceId}/channels/rule-test | 
*ChannelsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_version_rule_test_action_spaces_0**](docs/ChannelsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_version_rule_test_action_spaces_0) | **POST** /api/{baseSpaceId}/channels/rule-test | 
*ChannelsApi* | [**delete_on_background_response_descriptor_projects_channel_channel_resource**](docs/ChannelsApi.md#delete_on_background_response_descriptor_projects_channel_channel_resource) | **DELETE** /api/channels/{id} | Delete a ChannelResource by ID
*ChannelsApi* | [**delete_on_background_response_descriptor_projects_channel_channel_resource_spaces**](docs/ChannelsApi.md#delete_on_background_response_descriptor_projects_channel_channel_resource_spaces) | **DELETE** /api/{baseSpaceId}/channels/{id} | Delete a ChannelResource by ID
*ChannelsApi* | [**index_response_descriptor_projects_channel_channel_resource**](docs/ChannelsApi.md#index_response_descriptor_projects_channel_channel_resource) | **GET** /api/channels | Get a list of ChannelResources
*ChannelsApi* | [**index_response_descriptor_projects_channel_channel_resource_spaces**](docs/ChannelsApi.md#index_response_descriptor_projects_channel_channel_resource_spaces) | **GET** /api/{baseSpaceId}/channels | Get a list of ChannelResources
*ChannelsApi* | [**list_all_response_descriptor_projects_channel_channel_resource**](docs/ChannelsApi.md#list_all_response_descriptor_projects_channel_channel_resource) | **GET** /api/channels/all | Get a list of ChannelResources
*ChannelsApi* | [**list_all_response_descriptor_projects_channel_channel_resource_spaces**](docs/ChannelsApi.md#list_all_response_descriptor_projects_channel_channel_resource_spaces) | **GET** /api/{baseSpaceId}/channels/all | Get a list of ChannelResources
*ChannelsApi* | [**load_response_descriptor_projects_channel_channel_resource**](docs/ChannelsApi.md#load_response_descriptor_projects_channel_channel_resource) | **GET** /api/channels/{id} | Get a ChannelResource by ID
*ChannelsApi* | [**load_response_descriptor_projects_channel_channel_resource_spaces**](docs/ChannelsApi.md#load_response_descriptor_projects_channel_channel_resource_spaces) | **GET** /api/{baseSpaceId}/channels/{id} | Get a ChannelResource by ID
*ChannelsApi* | [**modify_response_descriptor_projects_channel_channel_resource**](docs/ChannelsApi.md#modify_response_descriptor_projects_channel_channel_resource) | **PUT** /api/channels/{id} | Modify a ChannelResource by ID
*ChannelsApi* | [**modify_response_descriptor_projects_channel_channel_resource_spaces**](docs/ChannelsApi.md#modify_response_descriptor_projects_channel_channel_resource_spaces) | **PUT** /api/{baseSpaceId}/channels/{id} | Modify a ChannelResource by ID
*CloudTemplateApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_cloud_template_metadata_responder**](docs/CloudTemplateApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_cloud_template_metadata_responder) | **POST** /api/cloudtemplate/{id}/metadata | 
*CommunityActionTemplatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_action_template_based_on_community_action_template_responder**](docs/CommunityActionTemplatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_action_template_based_on_community_action_template_responder) | **GET** /api/communityactiontemplates/{id}/actiontemplate/{spaceId?} | 
*CommunityActionTemplatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_community_action_template_installation_post_action_responder**](docs/CommunityActionTemplatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_community_action_template_installation_post_action_responder) | **POST** /api/communityactiontemplates/{id}/installation/{spaceId?} | 
*CommunityActionTemplatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_community_action_template_installation_put_action_responder**](docs/CommunityActionTemplatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_community_action_template_installation_put_action_responder) | **PUT** /api/communityactiontemplates/{id}/installation/{spaceId?} | 
*CommunityActionTemplatesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_community_action_template_logo_get_responder**](docs/CommunityActionTemplatesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_community_action_template_logo_get_responder) | **GET** /api/communityactiontemplates/{id}/logo | 
*CommunityActionTemplatesApi* | [**index_response_descriptor_projects_community_action_template_community_action_template_resource**](docs/CommunityActionTemplatesApi.md#index_response_descriptor_projects_community_action_template_community_action_template_resource) | **GET** /api/communityactiontemplates | Get a list of CommunityActionTemplateResources
*CommunityActionTemplatesApi* | [**load_response_descriptor_projects_community_action_template_community_action_template_resource**](docs/CommunityActionTemplatesApi.md#load_response_descriptor_projects_community_action_template_community_action_template_resource) | **GET** /api/communityactiontemplates/{id} | Get a CommunityActionTemplateResource by ID
*ConfigurationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_configuration_configuration_item_metadata_responder**](docs/ConfigurationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_configuration_configuration_item_metadata_responder) | **GET** /api/configuration/{id}/metadata | 
*ConfigurationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_configuration_configuration_item_update_responder**](docs/ConfigurationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_configuration_configuration_item_update_responder) | **PUT** /api/configuration/{id}/values | 
*ConfigurationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_configuration_configuration_item_values_responder**](docs/ConfigurationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_configuration_configuration_item_values_responder) | **GET** /api/configuration/{id}/values | 
*ConfigurationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_configuration_configuration_section_list_responder**](docs/ConfigurationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_configuration_configuration_section_list_responder) | **GET** /api/configuration | 
*ConfigurationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_configuration_configuration_section_metadata_responder**](docs/ConfigurationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_configuration_configuration_section_metadata_responder) | **GET** /api/configuration/{id} | 
*DashboardConfigurationsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_dashboard_configuration_get_action**](docs/DashboardConfigurationsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_dashboard_configuration_get_action) | **GET** /api/dashboardconfiguration | 
*DashboardConfigurationsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_dashboard_configuration_get_action_spaces**](docs/DashboardConfigurationsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_dashboard_configuration_get_action_spaces) | **GET** /api/{baseSpaceId}/dashboardconfiguration | 
*DashboardConfigurationsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_dashboard_configuration_update_action**](docs/DashboardConfigurationsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_dashboard_configuration_update_action) | **PUT** /api/dashboardconfiguration | 
*DashboardConfigurationsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_dashboard_configuration_update_action_spaces**](docs/DashboardConfigurationsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_dashboard_configuration_update_action_spaces) | **PUT** /api/{baseSpaceId}/dashboardconfiguration | 
*DashboardsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_dashboard_view_action**](docs/DashboardsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_dashboard_view_action) | **GET** /api/dashboard | 
*DashboardsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_dashboard_view_action_spaces**](docs/DashboardsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_dashboard_view_action_spaces) | **GET** /api/{baseSpaceId}/dashboard | 
*DashboardsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_dynamic_dashboard_view_action**](docs/DashboardsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_dynamic_dashboard_view_action) | **GET** /api/dashboard/dynamic | 
*DashboardsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_dynamic_dashboard_view_action_spaces**](docs/DashboardsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_dynamic_dashboard_view_action_spaces) | **GET** /api/{baseSpaceId}/dashboard/dynamic | 
*DeploymentProcessesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_deployment_process_update_action**](docs/DeploymentProcessesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_deployment_process_update_action) | **PUT** /api/deploymentprocesses/{id} | 
*DeploymentProcessesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_deployment_process_update_action_spaces**](docs/DeploymentProcessesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_deployment_process_update_action_spaces) | **PUT** /api/{baseSpaceId}/deploymentprocesses/{id} | 
*DeploymentProcessesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_release_template_action**](docs/DeploymentProcessesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_release_template_action) | **GET** /api/deploymentprocesses/{id}/template | 
*DeploymentProcessesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_release_template_action_spaces**](docs/DeploymentProcessesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_release_template_action_spaces) | **GET** /api/{baseSpaceId}/deploymentprocesses/{id}/template | 
*DeploymentProcessesApi* | [**index_response_descriptor_projects_deployment_process_deployment_process_resource**](docs/DeploymentProcessesApi.md#index_response_descriptor_projects_deployment_process_deployment_process_resource) | **GET** /api/deploymentprocesses | Get a list of DeploymentProcessResources
*DeploymentProcessesApi* | [**index_response_descriptor_projects_deployment_process_deployment_process_resource_spaces**](docs/DeploymentProcessesApi.md#index_response_descriptor_projects_deployment_process_deployment_process_resource_spaces) | **GET** /api/{baseSpaceId}/deploymentprocesses | Get a list of DeploymentProcessResources
*DeploymentProcessesApi* | [**load_response_descriptor_projects_deployment_process_deployment_process_resource**](docs/DeploymentProcessesApi.md#load_response_descriptor_projects_deployment_process_deployment_process_resource) | **GET** /api/deploymentprocesses/{id} | Get a DeploymentProcessResource by ID
*DeploymentProcessesApi* | [**load_response_descriptor_projects_deployment_process_deployment_process_resource_spaces**](docs/DeploymentProcessesApi.md#load_response_descriptor_projects_deployment_process_deployment_process_resource_spaces) | **GET** /api/{baseSpaceId}/deploymentprocesses/{id} | Get a DeploymentProcessResource by ID
*DeploymentsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_deployment_create_action**](docs/DeploymentsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_deployment_create_action) | **POST** /api/deployments | 
*DeploymentsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_deployment_create_action_spaces**](docs/DeploymentsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_deployment_create_action_spaces) | **POST** /api/{baseSpaceId}/deployments | 
*DeploymentsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_deployments_query_responder**](docs/DeploymentsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_deployments_query_responder) | **GET** /api/deployments | 
*DeploymentsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_deployments_query_responder_spaces**](docs/DeploymentsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_deployments_query_responder_spaces) | **GET** /api/{baseSpaceId}/deployments | 
*DeploymentsApi* | [**delete_on_background_response_descriptor_projects_deployment_deployment_resource**](docs/DeploymentsApi.md#delete_on_background_response_descriptor_projects_deployment_deployment_resource) | **DELETE** /api/deployments/{id} | Delete a DeploymentResource by ID
*DeploymentsApi* | [**delete_on_background_response_descriptor_projects_deployment_deployment_resource_spaces**](docs/DeploymentsApi.md#delete_on_background_response_descriptor_projects_deployment_deployment_resource_spaces) | **DELETE** /api/{baseSpaceId}/deployments/{id} | Delete a DeploymentResource by ID
*DeploymentsApi* | [**load_response_descriptor_projects_deployment_deployment_resource**](docs/DeploymentsApi.md#load_response_descriptor_projects_deployment_deployment_resource) | **GET** /api/deployments/{id} | Get a DeploymentResource by ID
*DeploymentsApi* | [**load_response_descriptor_projects_deployment_deployment_resource_spaces**](docs/DeploymentsApi.md#load_response_descriptor_projects_deployment_deployment_resource_spaces) | **GET** /api/{baseSpaceId}/deployments/{id} | Get a DeploymentResource by ID
*EnvironmentsApi* | [**create_response_descriptor_environments_deployment_environment_environment_resource**](docs/EnvironmentsApi.md#create_response_descriptor_environments_deployment_environment_environment_resource) | **POST** /api/environments | Create a EnvironmentResource
*EnvironmentsApi* | [**create_response_descriptor_environments_deployment_environment_environment_resource_spaces**](docs/EnvironmentsApi.md#create_response_descriptor_environments_deployment_environment_environment_resource_spaces) | **POST** /api/{baseSpaceId}/environments | Create a EnvironmentResource
*EnvironmentsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_environments_deployment_environment_settings_metadata_responder**](docs/EnvironmentsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_environments_deployment_environment_settings_metadata_responder) | **GET** /api/environments/{id}/metadata | 
*EnvironmentsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_environments_deployment_environment_settings_metadata_responder_spaces**](docs/EnvironmentsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_environments_deployment_environment_settings_metadata_responder_spaces) | **GET** /api/{baseSpaceId}/environments/{id}/metadata | 
*EnvironmentsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_sort_environments_responder**](docs/EnvironmentsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_sort_environments_responder) | **PUT** /api/environments/sortorder | 
*EnvironmentsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_sort_environments_responder_spaces**](docs/EnvironmentsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_sort_environments_responder_spaces) | **PUT** /api/{baseSpaceId}/environments/sortorder | 
*EnvironmentsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_variables_scoped_to_environment_responder**](docs/EnvironmentsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_variables_scoped_to_environment_responder) | **GET** /api/environments/{id}/singlyScopedVariableDetails | 
*EnvironmentsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_variables_scoped_to_environment_responder_spaces**](docs/EnvironmentsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_variables_scoped_to_environment_responder_spaces) | **GET** /api/{baseSpaceId}/environments/{id}/singlyScopedVariableDetails | 
*EnvironmentsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_environments_machines_responder**](docs/EnvironmentsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_environments_machines_responder) | **GET** /api/environments/{id}/machines | 
*EnvironmentsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_environments_machines_responder_spaces**](docs/EnvironmentsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_environments_machines_responder_spaces) | **GET** /api/{baseSpaceId}/environments/{id}/machines | 
*EnvironmentsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_infrastructure_summary_environments_summary_responder**](docs/EnvironmentsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_infrastructure_summary_environments_summary_responder) | **GET** /api/environments/summary | 
*EnvironmentsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_infrastructure_summary_environments_summary_responder_spaces**](docs/EnvironmentsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_infrastructure_summary_environments_summary_responder_spaces) | **GET** /api/{baseSpaceId}/environments/summary | 
*EnvironmentsApi* | [**delete_on_background_response_descriptor_environments_deployment_environment_environment_resource**](docs/EnvironmentsApi.md#delete_on_background_response_descriptor_environments_deployment_environment_environment_resource) | **DELETE** /api/environments/{id} | Delete a EnvironmentResource by ID
*EnvironmentsApi* | [**delete_on_background_response_descriptor_environments_deployment_environment_environment_resource_spaces**](docs/EnvironmentsApi.md#delete_on_background_response_descriptor_environments_deployment_environment_environment_resource_spaces) | **DELETE** /api/{baseSpaceId}/environments/{id} | Delete a EnvironmentResource by ID
*EnvironmentsApi* | [**index_response_descriptor_environments_deployment_environment_environment_resource**](docs/EnvironmentsApi.md#index_response_descriptor_environments_deployment_environment_environment_resource) | **GET** /api/environments | Get a list of EnvironmentResources
*EnvironmentsApi* | [**index_response_descriptor_environments_deployment_environment_environment_resource_spaces**](docs/EnvironmentsApi.md#index_response_descriptor_environments_deployment_environment_environment_resource_spaces) | **GET** /api/{baseSpaceId}/environments | Get a list of EnvironmentResources
*EnvironmentsApi* | [**list_all_response_descriptor_environments_deployment_environment_environment_resource**](docs/EnvironmentsApi.md#list_all_response_descriptor_environments_deployment_environment_environment_resource) | **GET** /api/environments/all | Get a list of EnvironmentResources
*EnvironmentsApi* | [**list_all_response_descriptor_environments_deployment_environment_environment_resource_spaces**](docs/EnvironmentsApi.md#list_all_response_descriptor_environments_deployment_environment_environment_resource_spaces) | **GET** /api/{baseSpaceId}/environments/all | Get a list of EnvironmentResources
*EnvironmentsApi* | [**load_response_descriptor_environments_deployment_environment_environment_resource**](docs/EnvironmentsApi.md#load_response_descriptor_environments_deployment_environment_environment_resource) | **GET** /api/environments/{id} | Get a EnvironmentResource by ID
*EnvironmentsApi* | [**load_response_descriptor_environments_deployment_environment_environment_resource_spaces**](docs/EnvironmentsApi.md#load_response_descriptor_environments_deployment_environment_environment_resource_spaces) | **GET** /api/{baseSpaceId}/environments/{id} | Get a EnvironmentResource by ID
*EnvironmentsApi* | [**modify_response_descriptor_environments_deployment_environment_environment_resource**](docs/EnvironmentsApi.md#modify_response_descriptor_environments_deployment_environment_environment_resource) | **PUT** /api/environments/{id} | Modify a EnvironmentResource by ID
*EnvironmentsApi* | [**modify_response_descriptor_environments_deployment_environment_environment_resource_spaces**](docs/EnvironmentsApi.md#modify_response_descriptor_environments_deployment_environment_environment_resource_spaces) | **PUT** /api/{baseSpaceId}/environments/{id} | Modify a EnvironmentResource by ID
*EventsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_event_agents_responder**](docs/EventsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_event_agents_responder) | **GET** /api/events/agents | 
*EventsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_event_agents_responder_spaces**](docs/EventsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_event_agents_responder_spaces) | **GET** /api/{baseSpaceId}/events/agents | 
*EventsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_event_categories_responder**](docs/EventsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_event_categories_responder) | **GET** /api/events/categories | 
*EventsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_event_categories_responder_spaces**](docs/EventsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_event_categories_responder_spaces) | **GET** /api/{baseSpaceId}/events/categories | 
*EventsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_event_document_types_responder**](docs/EventsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_event_document_types_responder) | **GET** /api/events/documenttypes | 
*EventsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_event_document_types_responder_spaces**](docs/EventsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_event_document_types_responder_spaces) | **GET** /api/{baseSpaceId}/events/documenttypes | 
*EventsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_event_groups_responder**](docs/EventsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_event_groups_responder) | **GET** /api/events/groups | 
*EventsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_event_groups_responder_spaces**](docs/EventsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_event_groups_responder_spaces) | **GET** /api/{baseSpaceId}/events/groups | 
*EventsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_events_responder**](docs/EventsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_events_responder) | **GET** /api/events | 
*EventsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_events_responder_spaces**](docs/EventsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_events_responder_spaces) | **GET** /api/{baseSpaceId}/events | 
*EventsApi* | [**load_response_descriptor_events_event_event_resource**](docs/EventsApi.md#load_response_descriptor_events_event_event_resource) | **GET** /api/events/{id} | Get a EventResource by ID
*EventsApi* | [**load_response_descriptor_events_event_event_resource_spaces**](docs/EventsApi.md#load_response_descriptor_events_event_event_resource_spaces) | **GET** /api/{baseSpaceId}/events/{id} | Get a EventResource by ID
*ExternalSecurityGroupsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_list_providers_that_support_external_security_groups_responder**](docs/ExternalSecurityGroupsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_list_providers_that_support_external_security_groups_responder) | **GET** /api/externalsecuritygroupproviders | 
*FeaturesConfigurationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_features_configuration_get_action**](docs/FeaturesConfigurationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_features_configuration_get_action) | **GET** /api/featuresconfiguration | 
*FeaturesConfigurationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_features_configuration_update_action**](docs/FeaturesConfigurationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_features_configuration_update_action) | **PUT** /api/featuresconfiguration | 
*FeedsApi* | [**create_response_descriptor_feed_feed_feed_resource**](docs/FeedsApi.md#create_response_descriptor_feed_feed_feed_resource) | **POST** /api/feeds | Create a FeedResource
*FeedsApi* | [**create_response_descriptor_feed_feed_feed_resource_spaces**](docs/FeedsApi.md#create_response_descriptor_feed_feed_feed_resource_spaces) | **POST** /api/{baseSpaceId}/feeds | Create a FeedResource
*FeedsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_search_action**](docs/FeedsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_search_action) | **GET** /api/feeds/{id}/packages/search | 
*FeedsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_search_action_spaces**](docs/FeedsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_search_action_spaces) | **GET** /api/{baseSpaceId}/feeds/{id}/packages/search | 
*FeedsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_version_search_action**](docs/FeedsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_version_search_action) | **GET** /api/feeds/{id}/packages/versions | 
*FeedsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_version_search_action_spaces**](docs/FeedsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_version_search_action_spaces) | **GET** /api/{baseSpaceId}/feeds/{id}/packages/versions | 
*FeedsApi* | [**custom_action_response_descriptor_octopus_server_web_api_nu_get_built_in_feed_stats_responder**](docs/FeedsApi.md#custom_action_response_descriptor_octopus_server_web_api_nu_get_built_in_feed_stats_responder) | **GET** /api/feeds/stats | 
*FeedsApi* | [**custom_action_response_descriptor_octopus_server_web_api_nu_get_built_in_feed_stats_responder_spaces**](docs/FeedsApi.md#custom_action_response_descriptor_octopus_server_web_api_nu_get_built_in_feed_stats_responder_spaces) | **GET** /api/{baseSpaceId}/feeds/stats | 
*FeedsApi* | [**delete_on_background_response_descriptor_feed_feed_feed_resource**](docs/FeedsApi.md#delete_on_background_response_descriptor_feed_feed_feed_resource) | **DELETE** /api/feeds/{id} | Delete a FeedResource by ID
*FeedsApi* | [**delete_on_background_response_descriptor_feed_feed_feed_resource_spaces**](docs/FeedsApi.md#delete_on_background_response_descriptor_feed_feed_feed_resource_spaces) | **DELETE** /api/{baseSpaceId}/feeds/{id} | Delete a FeedResource by ID
*FeedsApi* | [**modify_response_descriptor_feed_feed_feed_resource**](docs/FeedsApi.md#modify_response_descriptor_feed_feed_feed_resource) | **PUT** /api/feeds/{id} | Modify a FeedResource by ID
*FeedsApi* | [**modify_response_descriptor_feed_feed_feed_resource_spaces**](docs/FeedsApi.md#modify_response_descriptor_feed_feed_feed_resource_spaces) | **PUT** /api/{baseSpaceId}/feeds/{id} | Modify a FeedResource by ID
*FeedsApi* | [**octopus_server_web_api_feeds_feed_index_descriptor**](docs/FeedsApi.md#octopus_server_web_api_feeds_feed_index_descriptor) | **GET** /api/feeds | Get a list of FeedResources
*FeedsApi* | [**octopus_server_web_api_feeds_feed_index_descriptor_spaces**](docs/FeedsApi.md#octopus_server_web_api_feeds_feed_index_descriptor_spaces) | **GET** /api/{baseSpaceId}/feeds | Get a list of FeedResources
*FeedsApi* | [**octopus_server_web_api_feeds_feed_list_descriptor**](docs/FeedsApi.md#octopus_server_web_api_feeds_feed_list_descriptor) | **GET** /api/feeds/all | Get a list of FeedResources
*FeedsApi* | [**octopus_server_web_api_feeds_feed_list_descriptor_spaces**](docs/FeedsApi.md#octopus_server_web_api_feeds_feed_list_descriptor_spaces) | **GET** /api/{baseSpaceId}/feeds/all | Get a list of FeedResources
*FeedsApi* | [**octopus_server_web_api_feeds_feed_load_response_descriptor**](docs/FeedsApi.md#octopus_server_web_api_feeds_feed_load_response_descriptor) | **GET** /api/feeds/{id} | Get a FeedResource by ID
*FeedsApi* | [**octopus_server_web_api_feeds_feed_load_response_descriptor_spaces**](docs/FeedsApi.md#octopus_server_web_api_feeds_feed_load_response_descriptor_spaces) | **GET** /api/{baseSpaceId}/feeds/{id} | Get a FeedResource by ID
*HomeApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_home_responder**](docs/HomeApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_home_responder) | **GET** /api | 
*InterruptionsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_interruption_responsibility_responder**](docs/InterruptionsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_interruption_responsibility_responder) | **GET** /api/interruptions/{id}/responsible | 
*InterruptionsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_interruption_responsibility_responder_0**](docs/InterruptionsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_interruption_responsibility_responder_0) | **PUT** /api/interruptions/{id}/responsible | 
*InterruptionsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_interruption_responsibility_responder_spaces**](docs/InterruptionsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_interruption_responsibility_responder_spaces) | **GET** /api/{baseSpaceId}/interruptions/{id}/responsible | 
*InterruptionsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_interruption_responsibility_responder_spaces_0**](docs/InterruptionsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_interruption_responsibility_responder_spaces_0) | **PUT** /api/{baseSpaceId}/interruptions/{id}/responsible | 
*InterruptionsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_submit_interruption_responder**](docs/InterruptionsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_submit_interruption_responder) | **POST** /api/interruptions/{id}/submit | 
*InterruptionsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_submit_interruption_responder_spaces**](docs/InterruptionsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_submit_interruption_responder_spaces) | **POST** /api/{baseSpaceId}/interruptions/{id}/submit | 
*InterruptionsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_interruptions_responder**](docs/InterruptionsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_interruptions_responder) | **GET** /api/interruptions | 
*InterruptionsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_interruptions_responder_spaces**](docs/InterruptionsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_interruptions_responder_spaces) | **GET** /api/{baseSpaceId}/interruptions | 
*InterruptionsApi* | [**load_response_descriptor_server_tasks_interruption_interruption_resource**](docs/InterruptionsApi.md#load_response_descriptor_server_tasks_interruption_interruption_resource) | **GET** /api/interruptions/{id} | Get a InterruptionResource by ID
*InterruptionsApi* | [**load_response_descriptor_server_tasks_interruption_interruption_resource_spaces**](docs/InterruptionsApi.md#load_response_descriptor_server_tasks_interruption_interruption_resource_spaces) | **GET** /api/{baseSpaceId}/interruptions/{id} | Get a InterruptionResource by ID
*InvitationsApi* | [**create_response_descriptor_users_invitation_invitation_resource**](docs/InvitationsApi.md#create_response_descriptor_users_invitation_invitation_resource) | **POST** /api/users/invitations | Create a InvitationResource
*InvitationsApi* | [**create_response_descriptor_users_invitation_invitation_resource_spaces**](docs/InvitationsApi.md#create_response_descriptor_users_invitation_invitation_resource_spaces) | **POST** /api/{baseSpaceId}/users/invitations | Create a InvitationResource
*InvitationsApi* | [**load_response_descriptor_users_invitation_invitation_resource**](docs/InvitationsApi.md#load_response_descriptor_users_invitation_invitation_resource) | **GET** /api/users/invitations/{id} | Get a InvitationResource by ID
*InvitationsApi* | [**load_response_descriptor_users_invitation_invitation_resource_spaces**](docs/InvitationsApi.md#load_response_descriptor_users_invitation_invitation_resource_spaces) | **GET** /api/{baseSpaceId}/users/invitations/{id} | Get a InvitationResource by ID
*LetsEncryptApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_lets_encrypt_configuration_get_action**](docs/LetsEncryptApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_lets_encrypt_configuration_get_action) | **GET** api/letsencryptconfiguration | 
*LetsEncryptApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_lets_encrypt_configuration_update_action**](docs/LetsEncryptApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_lets_encrypt_configuration_update_action) | **PUT** api/letsencryptconfiguration | 
*LetsEncryptApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_lets_encrypt_http_challenge_responder**](docs/LetsEncryptApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_lets_encrypt_http_challenge_responder) | **GET** /.well-known/acme-challenge//{token} | 
*LibraryVariableSetsApi* | [**create_response_descriptor_variables_library_variable_set_library_variable_set_resource**](docs/LibraryVariableSetsApi.md#create_response_descriptor_variables_library_variable_set_library_variable_set_resource) | **POST** /api/libraryvariablesets | Create a LibraryVariableSetResource
*LibraryVariableSetsApi* | [**create_response_descriptor_variables_library_variable_set_library_variable_set_resource_spaces**](docs/LibraryVariableSetsApi.md#create_response_descriptor_variables_library_variable_set_library_variable_set_resource_spaces) | **POST** /api/{baseSpaceId}/libraryvariablesets | Create a LibraryVariableSetResource
*LibraryVariableSetsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_library_variable_set_usage_list_action**](docs/LibraryVariableSetsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_library_variable_set_usage_list_action) | **GET** /api/libraryvariablesets/{id}/usages | 
*LibraryVariableSetsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_library_variable_set_usage_list_action_spaces**](docs/LibraryVariableSetsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_library_variable_set_usage_list_action_spaces) | **GET** /api/{baseSpaceId}/libraryvariablesets/{id}/usages | 
*LibraryVariableSetsApi* | [**delete_on_background_response_descriptor_variables_library_variable_set_library_variable_set_resource**](docs/LibraryVariableSetsApi.md#delete_on_background_response_descriptor_variables_library_variable_set_library_variable_set_resource) | **DELETE** /api/libraryvariablesets/{id} | Delete a LibraryVariableSetResource by ID
*LibraryVariableSetsApi* | [**delete_on_background_response_descriptor_variables_library_variable_set_library_variable_set_resource_spaces**](docs/LibraryVariableSetsApi.md#delete_on_background_response_descriptor_variables_library_variable_set_library_variable_set_resource_spaces) | **DELETE** /api/{baseSpaceId}/libraryvariablesets/{id} | Delete a LibraryVariableSetResource by ID
*LibraryVariableSetsApi* | [**index_response_descriptor_variables_library_variable_set_library_variable_set_resource**](docs/LibraryVariableSetsApi.md#index_response_descriptor_variables_library_variable_set_library_variable_set_resource) | **GET** /api/libraryvariablesets | Get a list of LibraryVariableSetResources
*LibraryVariableSetsApi* | [**index_response_descriptor_variables_library_variable_set_library_variable_set_resource_spaces**](docs/LibraryVariableSetsApi.md#index_response_descriptor_variables_library_variable_set_library_variable_set_resource_spaces) | **GET** /api/{baseSpaceId}/libraryvariablesets | Get a list of LibraryVariableSetResources
*LibraryVariableSetsApi* | [**list_all_response_descriptor_variables_library_variable_set_library_variable_set_resource**](docs/LibraryVariableSetsApi.md#list_all_response_descriptor_variables_library_variable_set_library_variable_set_resource) | **GET** /api/libraryvariablesets/all | Get a list of LibraryVariableSetResources
*LibraryVariableSetsApi* | [**list_all_response_descriptor_variables_library_variable_set_library_variable_set_resource_spaces**](docs/LibraryVariableSetsApi.md#list_all_response_descriptor_variables_library_variable_set_library_variable_set_resource_spaces) | **GET** /api/{baseSpaceId}/libraryvariablesets/all | Get a list of LibraryVariableSetResources
*LibraryVariableSetsApi* | [**load_response_descriptor_variables_library_variable_set_library_variable_set_resource**](docs/LibraryVariableSetsApi.md#load_response_descriptor_variables_library_variable_set_library_variable_set_resource) | **GET** /api/libraryvariablesets/{id} | Get a LibraryVariableSetResource by ID
*LibraryVariableSetsApi* | [**load_response_descriptor_variables_library_variable_set_library_variable_set_resource_spaces**](docs/LibraryVariableSetsApi.md#load_response_descriptor_variables_library_variable_set_library_variable_set_resource_spaces) | **GET** /api/{baseSpaceId}/libraryvariablesets/{id} | Get a LibraryVariableSetResource by ID
*LibraryVariableSetsApi* | [**modify_response_descriptor_variables_library_variable_set_library_variable_set_resource**](docs/LibraryVariableSetsApi.md#modify_response_descriptor_variables_library_variable_set_library_variable_set_resource) | **PUT** /api/libraryvariablesets/{id} | Modify a LibraryVariableSetResource by ID
*LibraryVariableSetsApi* | [**modify_response_descriptor_variables_library_variable_set_library_variable_set_resource_spaces**](docs/LibraryVariableSetsApi.md#modify_response_descriptor_variables_library_variable_set_library_variable_set_resource_spaces) | **PUT** /api/{baseSpaceId}/libraryvariablesets/{id} | Modify a LibraryVariableSetResource by ID
*LicensesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_license_get_current_action**](docs/LicensesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_license_get_current_action) | **GET** /api/licenses/licenses-current | 
*LicensesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_license_put_current_action**](docs/LicensesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_license_put_current_action) | **PUT** /api/licenses/licenses-current | 
*LicensesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_license_status_get_current_action**](docs/LicensesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_license_status_get_current_action) | **GET** /api/licenses/licenses-current-status | 
*LifecyclesApi* | [**create_response_descriptor_lifecycles_lifecycle_lifecycle_resource**](docs/LifecyclesApi.md#create_response_descriptor_lifecycles_lifecycle_lifecycle_resource) | **POST** /api/lifecycles | Create a LifecycleResource
*LifecyclesApi* | [**create_response_descriptor_lifecycles_lifecycle_lifecycle_resource_spaces**](docs/LifecyclesApi.md#create_response_descriptor_lifecycles_lifecycle_lifecycle_resource_spaces) | **POST** /api/{baseSpaceId}/lifecycles | Create a LifecycleResource
*LifecyclesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_lifecycle_preview_action**](docs/LifecyclesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_lifecycle_preview_action) | **GET** /api/lifecycles/{id}/preview | 
*LifecyclesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_lifecycle_preview_action_spaces**](docs/LifecyclesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_lifecycle_preview_action_spaces) | **GET** /api/{baseSpaceId}/lifecycles/{id}/preview | 
*LifecyclesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_lifecycle_projects_action**](docs/LifecyclesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_lifecycle_projects_action) | **GET** /api/lifecycles/{id}/projects | 
*LifecyclesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_lifecycle_projects_action_spaces**](docs/LifecyclesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_lifecycle_projects_action_spaces) | **GET** /api/{baseSpaceId}/lifecycles/{id}/projects | 
*LifecyclesApi* | [**delete_on_background_response_descriptor_lifecycles_lifecycle_lifecycle_resource**](docs/LifecyclesApi.md#delete_on_background_response_descriptor_lifecycles_lifecycle_lifecycle_resource) | **DELETE** /api/lifecycles/{id} | Delete a LifecycleResource by ID
*LifecyclesApi* | [**delete_on_background_response_descriptor_lifecycles_lifecycle_lifecycle_resource_spaces**](docs/LifecyclesApi.md#delete_on_background_response_descriptor_lifecycles_lifecycle_lifecycle_resource_spaces) | **DELETE** /api/{baseSpaceId}/lifecycles/{id} | Delete a LifecycleResource by ID
*LifecyclesApi* | [**index_response_descriptor_lifecycles_lifecycle_lifecycle_resource**](docs/LifecyclesApi.md#index_response_descriptor_lifecycles_lifecycle_lifecycle_resource) | **GET** /api/lifecycles | Get a list of LifecycleResources
*LifecyclesApi* | [**index_response_descriptor_lifecycles_lifecycle_lifecycle_resource_spaces**](docs/LifecyclesApi.md#index_response_descriptor_lifecycles_lifecycle_lifecycle_resource_spaces) | **GET** /api/{baseSpaceId}/lifecycles | Get a list of LifecycleResources
*LifecyclesApi* | [**list_all_response_descriptor_lifecycles_lifecycle_lifecycle_resource**](docs/LifecyclesApi.md#list_all_response_descriptor_lifecycles_lifecycle_lifecycle_resource) | **GET** /api/lifecycles/all | Get a list of LifecycleResources
*LifecyclesApi* | [**list_all_response_descriptor_lifecycles_lifecycle_lifecycle_resource_spaces**](docs/LifecyclesApi.md#list_all_response_descriptor_lifecycles_lifecycle_lifecycle_resource_spaces) | **GET** /api/{baseSpaceId}/lifecycles/all | Get a list of LifecycleResources
*LifecyclesApi* | [**load_response_descriptor_lifecycles_lifecycle_lifecycle_resource**](docs/LifecyclesApi.md#load_response_descriptor_lifecycles_lifecycle_lifecycle_resource) | **GET** /api/lifecycles/{id} | Get a LifecycleResource by ID
*LifecyclesApi* | [**load_response_descriptor_lifecycles_lifecycle_lifecycle_resource_spaces**](docs/LifecyclesApi.md#load_response_descriptor_lifecycles_lifecycle_lifecycle_resource_spaces) | **GET** /api/{baseSpaceId}/lifecycles/{id} | Get a LifecycleResource by ID
*LifecyclesApi* | [**modify_response_descriptor_lifecycles_lifecycle_lifecycle_resource**](docs/LifecyclesApi.md#modify_response_descriptor_lifecycles_lifecycle_lifecycle_resource) | **PUT** /api/lifecycles/{id} | Modify a LifecycleResource by ID
*LifecyclesApi* | [**modify_response_descriptor_lifecycles_lifecycle_lifecycle_resource_spaces**](docs/LifecyclesApi.md#modify_response_descriptor_lifecycles_lifecycle_lifecycle_resource_spaces) | **PUT** /api/{baseSpaceId}/lifecycles/{id} | Modify a LifecycleResource by ID
*MachinePoliciesApi* | [**child_index_response_descriptor_policies_machine_policy_machines_deployment_targets_deployment_target_machine_policy_resource_deployment_target_resource**](docs/MachinePoliciesApi.md#child_index_response_descriptor_policies_machine_policy_machines_deployment_targets_deployment_target_machine_policy_resource_deployment_target_resource) | **GET** /api/machinepolicies/{id}/machines | Get a list of DeploymentTargetResources
*MachinePoliciesApi* | [**child_index_response_descriptor_policies_machine_policy_machines_deployment_targets_deployment_target_machine_policy_resource_deployment_target_resource_spaces**](docs/MachinePoliciesApi.md#child_index_response_descriptor_policies_machine_policy_machines_deployment_targets_deployment_target_machine_policy_resource_deployment_target_resource_spaces) | **GET** /api/{baseSpaceId}/machinepolicies/{id}/machines | Get a list of DeploymentTargetResources
*MachinePoliciesApi* | [**child_index_response_descriptor_policies_machine_policy_machines_workers_worker_machine_policy_resource_worker_resource**](docs/MachinePoliciesApi.md#child_index_response_descriptor_policies_machine_policy_machines_workers_worker_machine_policy_resource_worker_resource) | **GET** /api/machinepolicies/{id}/workers | Get a list of WorkerResources
*MachinePoliciesApi* | [**child_index_response_descriptor_policies_machine_policy_machines_workers_worker_machine_policy_resource_worker_resource_spaces**](docs/MachinePoliciesApi.md#child_index_response_descriptor_policies_machine_policy_machines_workers_worker_machine_policy_resource_worker_resource_spaces) | **GET** /api/{baseSpaceId}/machinepolicies/{id}/workers | Get a list of WorkerResources
*MachinePoliciesApi* | [**create_response_descriptor_policies_machine_policy_machine_policy_resource**](docs/MachinePoliciesApi.md#create_response_descriptor_policies_machine_policy_machine_policy_resource) | **POST** /api/machinepolicies | Create a MachinePolicyResource
*MachinePoliciesApi* | [**create_response_descriptor_policies_machine_policy_machine_policy_resource_spaces**](docs/MachinePoliciesApi.md#create_response_descriptor_policies_machine_policy_machine_policy_resource_spaces) | **POST** /api/{baseSpaceId}/machinepolicies | Create a MachinePolicyResource
*MachinePoliciesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_machine_policy_delete_action**](docs/MachinePoliciesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_machine_policy_delete_action) | **DELETE** /api/machinepolicies/{id} | 
*MachinePoliciesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_machine_policy_delete_action_spaces**](docs/MachinePoliciesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_machine_policy_delete_action_spaces) | **DELETE** /api/{baseSpaceId}/machinepolicies/{id} | 
*MachinePoliciesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_machine_policy_template_action**](docs/MachinePoliciesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_machine_policy_template_action) | **GET** /api/machinepolicies/template | 
*MachinePoliciesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_machine_policy_template_action_spaces**](docs/MachinePoliciesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_machine_policy_template_action_spaces) | **GET** /api/{baseSpaceId}/machinepolicies/template | 
*MachinePoliciesApi* | [**index_response_descriptor_policies_machine_policy_machine_policy_resource**](docs/MachinePoliciesApi.md#index_response_descriptor_policies_machine_policy_machine_policy_resource) | **GET** /api/machinepolicies | Get a list of MachinePolicyResources
*MachinePoliciesApi* | [**index_response_descriptor_policies_machine_policy_machine_policy_resource_spaces**](docs/MachinePoliciesApi.md#index_response_descriptor_policies_machine_policy_machine_policy_resource_spaces) | **GET** /api/{baseSpaceId}/machinepolicies | Get a list of MachinePolicyResources
*MachinePoliciesApi* | [**list_all_response_descriptor_policies_machine_policy_machine_policy_resource**](docs/MachinePoliciesApi.md#list_all_response_descriptor_policies_machine_policy_machine_policy_resource) | **GET** /api/machinepolicies/all | Get a list of MachinePolicyResources
*MachinePoliciesApi* | [**list_all_response_descriptor_policies_machine_policy_machine_policy_resource_spaces**](docs/MachinePoliciesApi.md#list_all_response_descriptor_policies_machine_policy_machine_policy_resource_spaces) | **GET** /api/{baseSpaceId}/machinepolicies/all | Get a list of MachinePolicyResources
*MachinePoliciesApi* | [**load_response_descriptor_policies_machine_policy_machine_policy_resource**](docs/MachinePoliciesApi.md#load_response_descriptor_policies_machine_policy_machine_policy_resource) | **GET** /api/machinepolicies/{id} | Get a MachinePolicyResource by ID
*MachinePoliciesApi* | [**load_response_descriptor_policies_machine_policy_machine_policy_resource_spaces**](docs/MachinePoliciesApi.md#load_response_descriptor_policies_machine_policy_machine_policy_resource_spaces) | **GET** /api/{baseSpaceId}/machinepolicies/{id} | Get a MachinePolicyResource by ID
*MachinePoliciesApi* | [**modify_response_descriptor_policies_machine_policy_machine_policy_resource**](docs/MachinePoliciesApi.md#modify_response_descriptor_policies_machine_policy_machine_policy_resource) | **PUT** /api/machinepolicies/{id} | Modify a MachinePolicyResource by ID
*MachinePoliciesApi* | [**modify_response_descriptor_policies_machine_policy_machine_policy_resource_spaces**](docs/MachinePoliciesApi.md#modify_response_descriptor_policies_machine_policy_machine_policy_resource_spaces) | **PUT** /api/{baseSpaceId}/machinepolicies/{id} | Modify a MachinePolicyResource by ID
*MachineRolesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_machine_roles_list_all_action**](docs/MachineRolesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_machine_roles_list_all_action) | **GET** /api/machineroles/all | 
*MachineRolesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_machine_roles_list_all_action_spaces**](docs/MachineRolesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_machine_roles_list_all_action_spaces) | **GET** /api/{baseSpaceId}/machineroles/all | 
*MachinesApi* | [**create_response_descriptor_machines_deployment_targets_deployment_target_deployment_target_resource**](docs/MachinesApi.md#create_response_descriptor_machines_deployment_targets_deployment_target_deployment_target_resource) | **POST** /api/machines | Create a DeploymentTargetResource
*MachinesApi* | [**create_response_descriptor_machines_deployment_targets_deployment_target_deployment_target_resource_spaces**](docs/MachinesApi.md#create_response_descriptor_machines_deployment_targets_deployment_target_deployment_target_resource_spaces) | **POST** /api/{baseSpaceId}/machines | Create a DeploymentTargetResource
*MachinesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_deployment_target_connection_status_responder**](docs/MachinesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_deployment_target_connection_status_responder) | **GET** /api/machines/{id}/connection | 
*MachinesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_deployment_target_connection_status_responder_spaces**](docs/MachinesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_deployment_target_connection_status_responder_spaces) | **GET** /api/{baseSpaceId}/machines/{id}/connection | 
*MachinesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_discover_deployment_target_responder**](docs/MachinesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_discover_deployment_target_responder) | **GET** /api/machines/discover | 
*MachinesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_discover_deployment_target_responder_spaces**](docs/MachinesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_discover_deployment_target_responder_spaces) | **GET** /api/{baseSpaceId}/machines/discover | 
*MachinesApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_deployment_target_responder**](docs/MachinesApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_deployment_target_responder) | **GET** /api/machines | 
*MachinesApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_deployment_target_responder_spaces**](docs/MachinesApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_deployment_target_responder_spaces) | **GET** /api/{baseSpaceId}/machines | 
*MachinesApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_machine_task_responder**](docs/MachinesApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_machine_task_responder) | **GET** /api/machines/{id}/tasks | 
*MachinesApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_machine_task_responder_spaces**](docs/MachinesApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_machine_task_responder_spaces) | **GET** /api/{baseSpaceId}/machines/{id}/tasks | 
*MachinesApi* | [**delete_on_background_response_descriptor_machines_deployment_targets_deployment_target_deployment_target_resource**](docs/MachinesApi.md#delete_on_background_response_descriptor_machines_deployment_targets_deployment_target_deployment_target_resource) | **DELETE** /api/machines/{id} | Delete a DeploymentTargetResource by ID
*MachinesApi* | [**delete_on_background_response_descriptor_machines_deployment_targets_deployment_target_deployment_target_resource_spaces**](docs/MachinesApi.md#delete_on_background_response_descriptor_machines_deployment_targets_deployment_target_deployment_target_resource_spaces) | **DELETE** /api/{baseSpaceId}/machines/{id} | Delete a DeploymentTargetResource by ID
*MachinesApi* | [**list_all_response_descriptor_machines_deployment_targets_deployment_target_deployment_target_resource**](docs/MachinesApi.md#list_all_response_descriptor_machines_deployment_targets_deployment_target_deployment_target_resource) | **GET** /api/machines/all | Get a list of DeploymentTargetResources
*MachinesApi* | [**list_all_response_descriptor_machines_deployment_targets_deployment_target_deployment_target_resource_spaces**](docs/MachinesApi.md#list_all_response_descriptor_machines_deployment_targets_deployment_target_deployment_target_resource_spaces) | **GET** /api/{baseSpaceId}/machines/all | Get a list of DeploymentTargetResources
*MachinesApi* | [**load_response_descriptor_machines_deployment_targets_deployment_target_deployment_target_resource**](docs/MachinesApi.md#load_response_descriptor_machines_deployment_targets_deployment_target_deployment_target_resource) | **GET** /api/machines/{id} | Get a DeploymentTargetResource by ID
*MachinesApi* | [**load_response_descriptor_machines_deployment_targets_deployment_target_deployment_target_resource_spaces**](docs/MachinesApi.md#load_response_descriptor_machines_deployment_targets_deployment_target_deployment_target_resource_spaces) | **GET** /api/{baseSpaceId}/machines/{id} | Get a DeploymentTargetResource by ID
*MachinesApi* | [**modify_response_descriptor_machines_deployment_targets_deployment_target_deployment_target_resource**](docs/MachinesApi.md#modify_response_descriptor_machines_deployment_targets_deployment_target_deployment_target_resource) | **PUT** /api/machines/{id} | Modify a DeploymentTargetResource by ID
*MachinesApi* | [**modify_response_descriptor_machines_deployment_targets_deployment_target_deployment_target_resource_spaces**](docs/MachinesApi.md#modify_response_descriptor_machines_deployment_targets_deployment_target_deployment_target_resource_spaces) | **PUT** /api/{baseSpaceId}/machines/{id} | Modify a DeploymentTargetResource by ID
*MaintenanceConfigurationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_maintenance_configuration_get_action**](docs/MaintenanceConfigurationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_maintenance_configuration_get_action) | **GET** /api/maintenanceconfiguration | 
*MaintenanceConfigurationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_maintenance_configuration_update_action**](docs/MaintenanceConfigurationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_maintenance_configuration_update_action) | **PUT** /api/maintenanceconfiguration | 
*MigrationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_migration_import_responder**](docs/MigrationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_migration_import_responder) | **POST** /api/migrations/import | 
*MigrationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_migration_partial_export_responder**](docs/MigrationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_migration_partial_export_responder) | **POST** /api/migrations/partialexport | 
*NuGetApi* | [**custom_action_response_descriptor_octopus_server_web_api_nu_get_nu_get_package_push_action**](docs/NuGetApi.md#custom_action_response_descriptor_octopus_server_web_api_nu_get_nu_get_package_push_action) | **PUT** /nuget/packages | 
*NuGetApi* | [**custom_action_response_descriptor_octopus_server_web_api_nu_get_nu_get_package_push_action_spaces**](docs/NuGetApi.md#custom_action_response_descriptor_octopus_server_web_api_nu_get_nu_get_package_push_action_spaces) | **PUT** /{baseSpaceId}/nuget/packages | 
*OctopusPackageMetadataApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_metadata_octopus_package_metadata_get_action**](docs/OctopusPackageMetadataApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_metadata_octopus_package_metadata_get_action) | **GET** /api/package-metadata/{id} | 
*OctopusPackageMetadataApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_metadata_octopus_package_metadata_get_action_spaces**](docs/OctopusPackageMetadataApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_metadata_octopus_package_metadata_get_action_spaces) | **GET** /api/{baseSpaceId}/package-metadata/{id} | 
*OctopusPackageMetadataApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_metadata_octopus_package_metadata_post_action**](docs/OctopusPackageMetadataApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_metadata_octopus_package_metadata_post_action) | **POST** /api/package-metadata | 
*OctopusPackageMetadataApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_metadata_octopus_package_metadata_post_action_spaces**](docs/OctopusPackageMetadataApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_metadata_octopus_package_metadata_post_action_spaces) | **POST** /api/{baseSpaceId}/package-metadata | 
*OctopusServerNodesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_load_balancer_ping_responder**](docs/OctopusServerNodesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_load_balancer_ping_responder) | **GET** /api/octopusservernodes/ping | 
*OctopusServerNodesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_octopus_server_cluster_summary_responder**](docs/OctopusServerNodesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_octopus_server_cluster_summary_responder) | **GET** /api/octopusservernodes/summary | 
*OctopusServerNodesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_octopus_server_node_details_responder**](docs/OctopusServerNodesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_octopus_server_node_details_responder) | **GET** /api/octopusservernodes/{id}/details | 
*OctopusServerNodesApi* | [**delete_on_background_response_descriptor_clustering_octopus_server_node_octopus_server_node_resource**](docs/OctopusServerNodesApi.md#delete_on_background_response_descriptor_clustering_octopus_server_node_octopus_server_node_resource) | **DELETE** /api/octopusservernodes/{id} | Delete a OctopusServerNodeResource by ID
*OctopusServerNodesApi* | [**index_response_descriptor_clustering_octopus_server_node_octopus_server_node_resource**](docs/OctopusServerNodesApi.md#index_response_descriptor_clustering_octopus_server_node_octopus_server_node_resource) | **GET** /api/octopusservernodes | Get a list of OctopusServerNodeResources
*OctopusServerNodesApi* | [**list_all_response_descriptor_clustering_octopus_server_node_octopus_server_node_resource**](docs/OctopusServerNodesApi.md#list_all_response_descriptor_clustering_octopus_server_node_octopus_server_node_resource) | **GET** /api/octopusservernodes/all | Get a list of OctopusServerNodeResources
*OctopusServerNodesApi* | [**load_response_descriptor_clustering_octopus_server_node_octopus_server_node_resource**](docs/OctopusServerNodesApi.md#load_response_descriptor_clustering_octopus_server_node_octopus_server_node_resource) | **GET** /api/octopusservernodes/{id} | Get a OctopusServerNodeResource by ID
*OctopusServerNodesApi* | [**modify_response_descriptor_clustering_octopus_server_node_octopus_server_node_resource**](docs/OctopusServerNodesApi.md#modify_response_descriptor_clustering_octopus_server_node_octopus_server_node_resource) | **PUT** /api/octopusservernodes/{id} | Modify a OctopusServerNodeResource by ID
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_list_notes_action**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_list_notes_action) | **GET** /api/packages/notes | 
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_list_notes_action_spaces**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_list_notes_action_spaces) | **GET** /api/{baseSpaceId}/packages/notes | 
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_notes_action**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_notes_action) | **GET** /api/feeds/{id}/packages/notes | 
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_notes_action_spaces**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_notes_action_spaces) | **GET** /api/{baseSpaceId}/feeds/{id}/packages/notes | 
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_delete_action**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_delete_action) | **DELETE** /api/packages/{id} | 
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_delete_action_0**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_delete_action_0) | **DELETE** /api/packages/bulk | 
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_delete_action_spaces**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_delete_action_spaces) | **DELETE** /api/{baseSpaceId}/packages/{id} | 
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_delete_action_spaces_0**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_delete_action_spaces_0) | **DELETE** /api/{baseSpaceId}/packages/bulk | 
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_delta_signature_action**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_delta_signature_action) | **GET** /api/packages/{packageId}/{version}/delta-signature | 
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_delta_signature_action_spaces**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_delta_signature_action_spaces) | **GET** /api/{baseSpaceId}/packages/{packageId}/{version}/delta-signature | 
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_delta_upload_action**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_delta_upload_action) | **POST** /api/packages/{packageId}/{baseVersion}/delta | 
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_delta_upload_action_spaces**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_delta_upload_action_spaces) | **POST** /api/{baseSpaceId}/packages/{packageId}/{baseVersion}/delta | 
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_get_action**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_get_action) | **GET** /api/packages/{id} | 
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_get_action_spaces**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_get_action_spaces) | **GET** /api/{baseSpaceId}/packages/{id} | 
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_get_raw_action**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_get_raw_action) | **GET** /api/packages/{id}/raw | 
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_get_raw_action_spaces**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_get_raw_action_spaces) | **GET** /api/{baseSpaceId}/packages/{id}/raw | 
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_list_action**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_list_action) | **GET** /api/packages | 
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_list_action_spaces**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_list_action_spaces) | **GET** /api/{baseSpaceId}/packages | 
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_upload_action**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_upload_action) | **POST** /api/packages/raw | 
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_upload_action_spaces**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_repository_package_repository_upload_action_spaces) | **POST** /api/{baseSpaceId}/packages/raw | 
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_search_action_old**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_search_action_old) | **GET** /api/feeds/{id}/packages | 
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_search_action_old_spaces**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_search_action_old_spaces) | **GET** /api/{baseSpaceId}/feeds/{id}/packages | 
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_version_search_action**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_version_search_action) | **GET** /api/feeds/{id}/packages/{packageId}/versions | 
*PackagesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_package_version_search_action_spaces**](docs/PackagesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_package_version_search_action_spaces) | **GET** /api/{baseSpaceId}/feeds/{id}/packages/{packageId}/versions | 
*PerformanceConfigurationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_performance_configuration_get_action**](docs/PerformanceConfigurationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_performance_configuration_get_action) | **GET** /api/performanceconfiguration | 
*PerformanceConfigurationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_performance_configuration_update_action**](docs/PerformanceConfigurationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_performance_configuration_update_action) | **PUT** /api/performanceconfiguration | 
*PermissionsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_permission_definitions_responder**](docs/PermissionsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_permission_definitions_responder) | **GET** /api/permissions/all | 
*ProgressionApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_progression_view_action**](docs/ProgressionApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_progression_view_action) | **GET** /api/progression/{id} | 
*ProgressionApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_progression_view_action_spaces**](docs/ProgressionApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_progression_view_action_spaces) | **GET** /api/{baseSpaceId}/progression/{id} | 
*ProjectGroupsApi* | [**child_index_response_descriptor_projects_project_group_projects_project_project_group_resource_project_resource**](docs/ProjectGroupsApi.md#child_index_response_descriptor_projects_project_group_projects_project_project_group_resource_project_resource) | **GET** /api/projectgroups/{id}/projects | Get a list of ProjectResources
*ProjectGroupsApi* | [**child_index_response_descriptor_projects_project_group_projects_project_project_group_resource_project_resource_spaces**](docs/ProjectGroupsApi.md#child_index_response_descriptor_projects_project_group_projects_project_project_group_resource_project_resource_spaces) | **GET** /api/{baseSpaceId}/projectgroups/{id}/projects | Get a list of ProjectResources
*ProjectGroupsApi* | [**create_response_descriptor_projects_project_group_project_group_resource**](docs/ProjectGroupsApi.md#create_response_descriptor_projects_project_group_project_group_resource) | **POST** /api/projectgroups | Create a ProjectGroupResource
*ProjectGroupsApi* | [**create_response_descriptor_projects_project_group_project_group_resource_spaces**](docs/ProjectGroupsApi.md#create_response_descriptor_projects_project_group_project_group_resource_spaces) | **POST** /api/{baseSpaceId}/projectgroups | Create a ProjectGroupResource
*ProjectGroupsApi* | [**delete_on_background_response_descriptor_projects_project_group_project_group_resource**](docs/ProjectGroupsApi.md#delete_on_background_response_descriptor_projects_project_group_project_group_resource) | **DELETE** /api/projectgroups/{id} | Delete a ProjectGroupResource by ID
*ProjectGroupsApi* | [**delete_on_background_response_descriptor_projects_project_group_project_group_resource_spaces**](docs/ProjectGroupsApi.md#delete_on_background_response_descriptor_projects_project_group_project_group_resource_spaces) | **DELETE** /api/{baseSpaceId}/projectgroups/{id} | Delete a ProjectGroupResource by ID
*ProjectGroupsApi* | [**index_response_descriptor_projects_project_group_project_group_resource**](docs/ProjectGroupsApi.md#index_response_descriptor_projects_project_group_project_group_resource) | **GET** /api/projectgroups | Get a list of ProjectGroupResources
*ProjectGroupsApi* | [**index_response_descriptor_projects_project_group_project_group_resource_spaces**](docs/ProjectGroupsApi.md#index_response_descriptor_projects_project_group_project_group_resource_spaces) | **GET** /api/{baseSpaceId}/projectgroups | Get a list of ProjectGroupResources
*ProjectGroupsApi* | [**list_all_response_descriptor_projects_project_group_project_group_resource**](docs/ProjectGroupsApi.md#list_all_response_descriptor_projects_project_group_project_group_resource) | **GET** /api/projectgroups/all | Get a list of ProjectGroupResources
*ProjectGroupsApi* | [**list_all_response_descriptor_projects_project_group_project_group_resource_spaces**](docs/ProjectGroupsApi.md#list_all_response_descriptor_projects_project_group_project_group_resource_spaces) | **GET** /api/{baseSpaceId}/projectgroups/all | Get a list of ProjectGroupResources
*ProjectGroupsApi* | [**load_response_descriptor_projects_project_group_project_group_resource**](docs/ProjectGroupsApi.md#load_response_descriptor_projects_project_group_project_group_resource) | **GET** /api/projectgroups/{id} | Get a ProjectGroupResource by ID
*ProjectGroupsApi* | [**load_response_descriptor_projects_project_group_project_group_resource_spaces**](docs/ProjectGroupsApi.md#load_response_descriptor_projects_project_group_project_group_resource_spaces) | **GET** /api/{baseSpaceId}/projectgroups/{id} | Get a ProjectGroupResource by ID
*ProjectGroupsApi* | [**modify_response_descriptor_projects_project_group_project_group_resource**](docs/ProjectGroupsApi.md#modify_response_descriptor_projects_project_group_project_group_resource) | **PUT** /api/projectgroups/{id} | Modify a ProjectGroupResource by ID
*ProjectGroupsApi* | [**modify_response_descriptor_projects_project_group_project_group_resource_spaces**](docs/ProjectGroupsApi.md#modify_response_descriptor_projects_project_group_project_group_resource_spaces) | **PUT** /api/{baseSpaceId}/projectgroups/{id} | Modify a ProjectGroupResource by ID
*ProjectTriggersApi* | [**child_index_response_descriptor_projects_project_projects_project_trigger_project_trigger_project_resource_project_trigger_resource**](docs/ProjectTriggersApi.md#child_index_response_descriptor_projects_project_projects_project_trigger_project_trigger_project_resource_project_trigger_resource) | **GET** /api/projects/{id}/triggers | Get a list of ProjectTriggerResources
*ProjectTriggersApi* | [**child_index_response_descriptor_projects_project_projects_project_trigger_project_trigger_project_resource_project_trigger_resource_spaces**](docs/ProjectTriggersApi.md#child_index_response_descriptor_projects_project_projects_project_trigger_project_trigger_project_resource_project_trigger_resource_spaces) | **GET** /api/{baseSpaceId}/projects/{id}/triggers | Get a list of ProjectTriggerResources
*ProjectTriggersApi* | [**create_response_descriptor_projects_project_trigger_project_trigger_project_trigger_resource**](docs/ProjectTriggersApi.md#create_response_descriptor_projects_project_trigger_project_trigger_project_trigger_resource) | **POST** /api/projecttriggers | Create a ProjectTriggerResource
*ProjectTriggersApi* | [**create_response_descriptor_projects_project_trigger_project_trigger_project_trigger_resource_spaces**](docs/ProjectTriggersApi.md#create_response_descriptor_projects_project_trigger_project_trigger_project_trigger_resource_spaces) | **POST** /api/{baseSpaceId}/projecttriggers | Create a ProjectTriggerResource
*ProjectTriggersApi* | [**delete_on_background_response_descriptor_projects_project_trigger_project_trigger_project_trigger_resource**](docs/ProjectTriggersApi.md#delete_on_background_response_descriptor_projects_project_trigger_project_trigger_project_trigger_resource) | **DELETE** /api/projecttriggers/{id} | Delete a ProjectTriggerResource by ID
*ProjectTriggersApi* | [**delete_on_background_response_descriptor_projects_project_trigger_project_trigger_project_trigger_resource_spaces**](docs/ProjectTriggersApi.md#delete_on_background_response_descriptor_projects_project_trigger_project_trigger_project_trigger_resource_spaces) | **DELETE** /api/{baseSpaceId}/projecttriggers/{id} | Delete a ProjectTriggerResource by ID
*ProjectTriggersApi* | [**index_response_descriptor_projects_project_trigger_project_trigger_project_trigger_resource**](docs/ProjectTriggersApi.md#index_response_descriptor_projects_project_trigger_project_trigger_project_trigger_resource) | **GET** /api/projecttriggers | Get a list of ProjectTriggerResources
*ProjectTriggersApi* | [**index_response_descriptor_projects_project_trigger_project_trigger_project_trigger_resource_spaces**](docs/ProjectTriggersApi.md#index_response_descriptor_projects_project_trigger_project_trigger_project_trigger_resource_spaces) | **GET** /api/{baseSpaceId}/projecttriggers | Get a list of ProjectTriggerResources
*ProjectTriggersApi* | [**load_response_descriptor_projects_project_trigger_project_trigger_project_trigger_resource**](docs/ProjectTriggersApi.md#load_response_descriptor_projects_project_trigger_project_trigger_project_trigger_resource) | **GET** /api/projecttriggers/{id} | Get a ProjectTriggerResource by ID
*ProjectTriggersApi* | [**load_response_descriptor_projects_project_trigger_project_trigger_project_trigger_resource_spaces**](docs/ProjectTriggersApi.md#load_response_descriptor_projects_project_trigger_project_trigger_project_trigger_resource_spaces) | **GET** /api/{baseSpaceId}/projecttriggers/{id} | Get a ProjectTriggerResource by ID
*ProjectTriggersApi* | [**modify_response_descriptor_projects_project_trigger_project_trigger_project_trigger_resource**](docs/ProjectTriggersApi.md#modify_response_descriptor_projects_project_trigger_project_trigger_project_trigger_resource) | **PUT** /api/projecttriggers/{id} | Modify a ProjectTriggerResource by ID
*ProjectTriggersApi* | [**modify_response_descriptor_projects_project_trigger_project_trigger_project_trigger_resource_spaces**](docs/ProjectTriggersApi.md#modify_response_descriptor_projects_project_trigger_project_trigger_project_trigger_resource_spaces) | **PUT** /api/{baseSpaceId}/projecttriggers/{id} | Modify a ProjectTriggerResource by ID
*ProjectsApi* | [**create_response_descriptor_projects_project_project_resource**](docs/ProjectsApi.md#create_response_descriptor_projects_project_project_resource) | **POST** /api/projects | Create a ProjectResource
*ProjectsApi* | [**create_response_descriptor_projects_project_project_resource_spaces**](docs/ProjectsApi.md#create_response_descriptor_projects_project_project_resource_spaces) | **POST** /api/{baseSpaceId}/projects | Create a ProjectResource
*ProjectsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_project_logo_get_responder**](docs/ProjectsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_project_logo_get_responder) | **GET** /api/projects/{id}/logo | 
*ProjectsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_project_logo_get_responder_spaces**](docs/ProjectsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_project_logo_get_responder_spaces) | **GET** /api/{baseSpaceId}/projects/{id}/logo | 
*ProjectsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_project_logo_put_responder**](docs/ProjectsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_project_logo_put_responder) | **PUT** /api/projects/{id}/logo | 
*ProjectsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_project_logo_put_responder_0**](docs/ProjectsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_project_logo_put_responder_0) | **POST** /api/projects/{id}/logo | 
*ProjectsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_project_logo_put_responder_spaces**](docs/ProjectsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_project_logo_put_responder_spaces) | **PUT** /api/{baseSpaceId}/projects/{id}/logo | 
*ProjectsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_project_logo_put_responder_spaces_0**](docs/ProjectsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_project_logo_put_responder_spaces_0) | **POST** /api/{baseSpaceId}/projects/{id}/logo | 
*ProjectsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_projects_project_settings_metadata_responder**](docs/ProjectsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_projects_project_settings_metadata_responder) | **GET** /api/projects/{id}/metadata | 
*ProjectsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_projects_project_settings_metadata_responder_spaces**](docs/ProjectsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_projects_project_settings_metadata_responder_spaces) | **GET** /api/{baseSpaceId}/projects/{id}/metadata | 
*ProjectsApi* | [**delete_on_background_response_descriptor_projects_project_project_resource**](docs/ProjectsApi.md#delete_on_background_response_descriptor_projects_project_project_resource) | **DELETE** /api/projects/{id} | Delete a ProjectResource by ID
*ProjectsApi* | [**delete_on_background_response_descriptor_projects_project_project_resource_spaces**](docs/ProjectsApi.md#delete_on_background_response_descriptor_projects_project_project_resource_spaces) | **DELETE** /api/{baseSpaceId}/projects/{id} | Delete a ProjectResource by ID
*ProjectsApi* | [**index_response_descriptor_projects_project_project_resource**](docs/ProjectsApi.md#index_response_descriptor_projects_project_project_resource) | **GET** /api/projects | Get a list of ProjectResources
*ProjectsApi* | [**index_response_descriptor_projects_project_project_resource_spaces**](docs/ProjectsApi.md#index_response_descriptor_projects_project_project_resource_spaces) | **GET** /api/{baseSpaceId}/projects | Get a list of ProjectResources
*ProjectsApi* | [**list_all_response_descriptor_projects_project_project_resource**](docs/ProjectsApi.md#list_all_response_descriptor_projects_project_project_resource) | **GET** /api/projects/all | Get a list of ProjectResources
*ProjectsApi* | [**list_all_response_descriptor_projects_project_project_resource_spaces**](docs/ProjectsApi.md#list_all_response_descriptor_projects_project_project_resource_spaces) | **GET** /api/{baseSpaceId}/projects/all | Get a list of ProjectResources
*ProjectsApi* | [**load_by_id_or_slug_response_descriptor_projects_project_project_resource**](docs/ProjectsApi.md#load_by_id_or_slug_response_descriptor_projects_project_project_resource) | **GET** /api/projects/{idOrSlug} | Get a ProjectResource by ID or slug
*ProjectsApi* | [**load_by_id_or_slug_response_descriptor_projects_project_project_resource_spaces**](docs/ProjectsApi.md#load_by_id_or_slug_response_descriptor_projects_project_project_resource_spaces) | **GET** /api/{baseSpaceId}/projects/{idOrSlug} | Get a ProjectResource by ID or slug
*ProjectsApi* | [**modify_response_descriptor_projects_project_project_resource**](docs/ProjectsApi.md#modify_response_descriptor_projects_project_project_resource) | **PUT** /api/projects/{id} | Modify a ProjectResource by ID
*ProjectsApi* | [**modify_response_descriptor_projects_project_project_resource_spaces**](docs/ProjectsApi.md#modify_response_descriptor_projects_project_project_resource_spaces) | **PUT** /api/{baseSpaceId}/projects/{id} | Modify a ProjectResource by ID
*ProxiesApi* | [**create_response_descriptor_machines_proxy_proxy_resource**](docs/ProxiesApi.md#create_response_descriptor_machines_proxy_proxy_resource) | **POST** /api/proxies | Create a ProxyResource
*ProxiesApi* | [**create_response_descriptor_machines_proxy_proxy_resource_spaces**](docs/ProxiesApi.md#create_response_descriptor_machines_proxy_proxy_resource_spaces) | **POST** /api/{baseSpaceId}/proxies | Create a ProxyResource
*ProxiesApi* | [**delete_on_background_response_descriptor_machines_proxy_proxy_resource**](docs/ProxiesApi.md#delete_on_background_response_descriptor_machines_proxy_proxy_resource) | **DELETE** /api/proxies/{id} | Delete a ProxyResource by ID
*ProxiesApi* | [**delete_on_background_response_descriptor_machines_proxy_proxy_resource_spaces**](docs/ProxiesApi.md#delete_on_background_response_descriptor_machines_proxy_proxy_resource_spaces) | **DELETE** /api/{baseSpaceId}/proxies/{id} | Delete a ProxyResource by ID
*ProxiesApi* | [**index_response_descriptor_machines_proxy_proxy_resource**](docs/ProxiesApi.md#index_response_descriptor_machines_proxy_proxy_resource) | **GET** /api/proxies | Get a list of ProxyResources
*ProxiesApi* | [**index_response_descriptor_machines_proxy_proxy_resource_spaces**](docs/ProxiesApi.md#index_response_descriptor_machines_proxy_proxy_resource_spaces) | **GET** /api/{baseSpaceId}/proxies | Get a list of ProxyResources
*ProxiesApi* | [**list_all_response_descriptor_machines_proxy_proxy_resource**](docs/ProxiesApi.md#list_all_response_descriptor_machines_proxy_proxy_resource) | **GET** /api/proxies/all | Get a list of ProxyResources
*ProxiesApi* | [**list_all_response_descriptor_machines_proxy_proxy_resource_spaces**](docs/ProxiesApi.md#list_all_response_descriptor_machines_proxy_proxy_resource_spaces) | **GET** /api/{baseSpaceId}/proxies/all | Get a list of ProxyResources
*ProxiesApi* | [**load_response_descriptor_machines_proxy_proxy_resource**](docs/ProxiesApi.md#load_response_descriptor_machines_proxy_proxy_resource) | **GET** /api/proxies/{id} | Get a ProxyResource by ID
*ProxiesApi* | [**load_response_descriptor_machines_proxy_proxy_resource_spaces**](docs/ProxiesApi.md#load_response_descriptor_machines_proxy_proxy_resource_spaces) | **GET** /api/{baseSpaceId}/proxies/{id} | Get a ProxyResource by ID
*ProxiesApi* | [**modify_response_descriptor_machines_proxy_proxy_resource**](docs/ProxiesApi.md#modify_response_descriptor_machines_proxy_proxy_resource) | **PUT** /api/proxies/{id} | Modify a ProxyResource by ID
*ProxiesApi* | [**modify_response_descriptor_machines_proxy_proxy_resource_spaces**](docs/ProxiesApi.md#modify_response_descriptor_machines_proxy_proxy_resource_spaces) | **PUT** /api/{baseSpaceId}/proxies/{id} | Modify a ProxyResource by ID
*ReleasesApi* | [**child_index_response_descriptor_projects_project_projects_release_project_resource_release_resource**](docs/ReleasesApi.md#child_index_response_descriptor_projects_project_projects_release_project_resource_release_resource) | **GET** /api/projects/{id}/releases | Get a list of ReleaseResources
*ReleasesApi* | [**child_index_response_descriptor_projects_project_projects_release_project_resource_release_resource_spaces**](docs/ReleasesApi.md#child_index_response_descriptor_projects_project_projects_release_project_resource_release_resource_spaces) | **GET** /api/{baseSpaceId}/projects/{id}/releases | Get a list of ReleaseResources
*ReleasesApi* | [**child_index_response_descriptor_projects_release_projects_deployment_release_resource_deployment_resource**](docs/ReleasesApi.md#child_index_response_descriptor_projects_release_projects_deployment_release_resource_deployment_resource) | **GET** /api/releases/{id}/deployments | Get a list of DeploymentResources
*ReleasesApi* | [**child_index_response_descriptor_projects_release_projects_deployment_release_resource_deployment_resource_spaces**](docs/ReleasesApi.md#child_index_response_descriptor_projects_release_projects_deployment_release_resource_deployment_resource_spaces) | **GET** /api/{baseSpaceId}/releases/{id}/deployments | Get a list of DeploymentResources
*ReleasesApi* | [**create_response_descriptor_projects_release_release_resource**](docs/ReleasesApi.md#create_response_descriptor_projects_release_release_resource) | **POST** /api/releases | Create a ReleaseResource
*ReleasesApi* | [**create_response_descriptor_projects_release_release_resource_spaces**](docs/ReleasesApi.md#create_response_descriptor_projects_release_release_resource_spaces) | **POST** /api/{baseSpaceId}/releases | Create a ReleaseResource
*ReleasesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_defect_reported_responder**](docs/ReleasesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_defect_reported_responder) | **POST** /api/releases/{id}/defects | 
*ReleasesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_defect_reported_responder_spaces**](docs/ReleasesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_defect_reported_responder_spaces) | **POST** /api/{baseSpaceId}/releases/{id}/defects | 
*ReleasesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_defect_resolved_responder**](docs/ReleasesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_defect_resolved_responder) | **POST** /api/releases/{id}/defects/resolve | 
*ReleasesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_defect_resolved_responder_spaces**](docs/ReleasesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_defect_resolved_responder_spaces) | **POST** /api/{baseSpaceId}/releases/{id}/defects/resolve | 
*ReleasesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_deployment_preview_action**](docs/ReleasesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_deployment_preview_action) | **GET** /api/releases/{id}/deployments/preview/{environment} | 
*ReleasesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_deployment_preview_action_0**](docs/ReleasesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_deployment_preview_action_0) | **GET** /api/releases/{id}/deployments/preview/{environment}/{tenant} | 
*ReleasesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_deployment_preview_action_spaces**](docs/ReleasesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_deployment_preview_action_spaces) | **GET** /api/{baseSpaceId}/releases/{id}/deployments/preview/{environment} | 
*ReleasesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_deployment_preview_action_spaces_0**](docs/ReleasesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_deployment_preview_action_spaces_0) | **GET** /api/{baseSpaceId}/releases/{id}/deployments/preview/{environment}/{tenant} | 
*ReleasesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_deployment_template_action**](docs/ReleasesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_deployment_template_action) | **GET** /api/releases/{id}/deployments/template | 
*ReleasesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_deployment_template_action_spaces**](docs/ReleasesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_deployment_template_action_spaces) | **GET** /api/{baseSpaceId}/releases/{id}/deployments/template | 
*ReleasesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_release_by_project_and_version_responder**](docs/ReleasesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_release_by_project_and_version_responder) | **GET** /api/projects/{id}/releases/{version} | 
*ReleasesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_release_by_project_and_version_responder_spaces**](docs/ReleasesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_release_by_project_and_version_responder_spaces) | **GET** /api/{baseSpaceId}/projects/{id}/releases/{version} | 
*ReleasesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_release_lifecycle_progression_action**](docs/ReleasesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_release_lifecycle_progression_action) | **GET** /api/releases/{id}/progression | 
*ReleasesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_release_lifecycle_progression_action_spaces**](docs/ReleasesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_release_lifecycle_progression_action_spaces) | **GET** /api/{baseSpaceId}/releases/{id}/progression | 
*ReleasesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_release_snapshot_variables_action**](docs/ReleasesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_release_snapshot_variables_action) | **POST** /api/releases/{id}/snapshot-variables | 
*ReleasesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_release_snapshot_variables_action_spaces**](docs/ReleasesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_release_snapshot_variables_action_spaces) | **POST** /api/{baseSpaceId}/releases/{id}/snapshot-variables | 
*ReleasesApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_defects_responder**](docs/ReleasesApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_defects_responder) | **GET** /api/releases/{id}/defects | 
*ReleasesApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_defects_responder_spaces**](docs/ReleasesApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_defects_responder_spaces) | **GET** /api/{baseSpaceId}/releases/{id}/defects | 
*ReleasesApi* | [**delete_on_background_response_descriptor_projects_release_release_resource**](docs/ReleasesApi.md#delete_on_background_response_descriptor_projects_release_release_resource) | **DELETE** /api/releases/{id} | Delete a ReleaseResource by ID
*ReleasesApi* | [**delete_on_background_response_descriptor_projects_release_release_resource_spaces**](docs/ReleasesApi.md#delete_on_background_response_descriptor_projects_release_release_resource_spaces) | **DELETE** /api/{baseSpaceId}/releases/{id} | Delete a ReleaseResource by ID
*ReleasesApi* | [**index_response_descriptor_projects_release_release_resource**](docs/ReleasesApi.md#index_response_descriptor_projects_release_release_resource) | **GET** /api/releases | Get a list of ReleaseResources
*ReleasesApi* | [**index_response_descriptor_projects_release_release_resource_spaces**](docs/ReleasesApi.md#index_response_descriptor_projects_release_release_resource_spaces) | **GET** /api/{baseSpaceId}/releases | Get a list of ReleaseResources
*ReleasesApi* | [**load_response_descriptor_projects_release_release_resource**](docs/ReleasesApi.md#load_response_descriptor_projects_release_release_resource) | **GET** /api/releases/{id} | Get a ReleaseResource by ID
*ReleasesApi* | [**load_response_descriptor_projects_release_release_resource_spaces**](docs/ReleasesApi.md#load_response_descriptor_projects_release_release_resource_spaces) | **GET** /api/{baseSpaceId}/releases/{id} | Get a ReleaseResource by ID
*ReleasesApi* | [**modify_response_descriptor_projects_release_release_resource**](docs/ReleasesApi.md#modify_response_descriptor_projects_release_release_resource) | **PUT** /api/releases/{id} | Modify a ReleaseResource by ID
*ReleasesApi* | [**modify_response_descriptor_projects_release_release_resource_spaces**](docs/ReleasesApi.md#modify_response_descriptor_projects_release_release_resource_spaces) | **PUT** /api/{baseSpaceId}/releases/{id} | Modify a ReleaseResource by ID
*ReportingApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_deployments_by_project_report_responder**](docs/ReportingApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_deployments_by_project_report_responder) | **GET** /api/reporting/deployments-counted-by-week | 
*ReportingApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_deployments_by_project_report_responder_spaces**](docs/ReportingApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_deployments_by_project_report_responder_spaces) | **GET** /api/{baseSpaceId}/reporting/deployments-counted-by-week | 
*ReportingApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_deployments_xml_responder**](docs/ReportingApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_deployments_xml_responder) | **GET** /api/reporting/deployments/xml | 
*ReportingApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_deployments_xml_responder_spaces**](docs/ReportingApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_deployments_xml_responder_spaces) | **GET** /api/{baseSpaceId}/reporting/deployments/xml | 
*SchedulerApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_scheduled_task_details_responder**](docs/SchedulerApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_scheduled_task_details_responder) | **GET** /api/scheduler/{name}/logs | 
*SchedulerApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_scheduled_task_raw_details_responder**](docs/SchedulerApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_scheduled_task_raw_details_responder) | **GET** /api/scheduler/{name}/logs/raw | 
*SchedulerApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_scheduler_get_responder**](docs/SchedulerApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_scheduler_get_responder) | **GET** /api/scheduler | 
*SchedulerApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_scheduler_start_responder**](docs/SchedulerApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_scheduler_start_responder) | **GET** /api/scheduler/start | 
*SchedulerApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_scheduler_stop_responder**](docs/SchedulerApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_scheduler_stop_responder) | **GET** /api/scheduler/stop | 
*SchedulerApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_scheduler_trigger_responder**](docs/SchedulerApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_scheduler_trigger_responder) | **GET** /api/scheduler/trigger | 
*ScopedUserRoleApi* | [**create_response_descriptor_users_scoped_user_role_scoped_user_role_resource**](docs/ScopedUserRoleApi.md#create_response_descriptor_users_scoped_user_role_scoped_user_role_resource) | **POST** /api/scopeduserroles | Create a ScopedUserRoleResource
*ScopedUserRoleApi* | [**create_response_descriptor_users_scoped_user_role_scoped_user_role_resource_spaces**](docs/ScopedUserRoleApi.md#create_response_descriptor_users_scoped_user_role_scoped_user_role_resource_spaces) | **POST** /api/{baseSpaceId}/scopeduserroles | Create a ScopedUserRoleResource
*ScopedUserRoleApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_scoped_user_role_responder**](docs/ScopedUserRoleApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_scoped_user_role_responder) | **GET** /api/scopeduserroles | 
*ScopedUserRoleApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_scoped_user_role_responder_spaces**](docs/ScopedUserRoleApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_scoped_user_role_responder_spaces) | **GET** /api/{baseSpaceId}/scopeduserroles | 
*ScopedUserRoleApi* | [**delete_on_background_response_descriptor_users_scoped_user_role_scoped_user_role_resource**](docs/ScopedUserRoleApi.md#delete_on_background_response_descriptor_users_scoped_user_role_scoped_user_role_resource) | **DELETE** /api/scopeduserroles/{id} | Delete a ScopedUserRoleResource by ID
*ScopedUserRoleApi* | [**delete_on_background_response_descriptor_users_scoped_user_role_scoped_user_role_resource_spaces**](docs/ScopedUserRoleApi.md#delete_on_background_response_descriptor_users_scoped_user_role_scoped_user_role_resource_spaces) | **DELETE** /api/{baseSpaceId}/scopeduserroles/{id} | Delete a ScopedUserRoleResource by ID
*ScopedUserRoleApi* | [**load_response_descriptor_users_scoped_user_role_scoped_user_role_resource**](docs/ScopedUserRoleApi.md#load_response_descriptor_users_scoped_user_role_scoped_user_role_resource) | **GET** /api/scopeduserroles/{id} | Get a ScopedUserRoleResource by ID
*ScopedUserRoleApi* | [**load_response_descriptor_users_scoped_user_role_scoped_user_role_resource_spaces**](docs/ScopedUserRoleApi.md#load_response_descriptor_users_scoped_user_role_scoped_user_role_resource_spaces) | **GET** /api/{baseSpaceId}/scopeduserroles/{id} | Get a ScopedUserRoleResource by ID
*ScopedUserRoleApi* | [**modify_response_descriptor_users_scoped_user_role_scoped_user_role_resource**](docs/ScopedUserRoleApi.md#modify_response_descriptor_users_scoped_user_role_scoped_user_role_resource) | **PUT** /api/scopeduserroles/{id} | Modify a ScopedUserRoleResource by ID
*ScopedUserRoleApi* | [**modify_response_descriptor_users_scoped_user_role_scoped_user_role_resource_spaces**](docs/ScopedUserRoleApi.md#modify_response_descriptor_users_scoped_user_role_scoped_user_role_resource_spaces) | **PUT** /api/{baseSpaceId}/scopeduserroles/{id} | Modify a ScopedUserRoleResource by ID
*ServerConfigurationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_server_configuration_get_action**](docs/ServerConfigurationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_server_configuration_get_action) | **GET** /api/serverconfiguration | 
*ServerConfigurationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_server_configuration_settings_list_action**](docs/ServerConfigurationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_server_configuration_settings_list_action) | **GET** /api/serverconfiguration/settings | 
*ServerConfigurationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_server_configuration_update_action**](docs/ServerConfigurationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_server_configuration_update_action) | **PUT** /api/serverconfiguration | 
*ServerStatusApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_status_extension_stats_responder**](docs/ServerStatusApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_status_extension_stats_responder) | **GET** /api/serverstatus/extensions | 
*ServerStatusApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_status_recent_logs_responder**](docs/ServerStatusApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_status_recent_logs_responder) | **GET** /api/serverstatus/logs | 
*ServerStatusApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_status_server_status_health_responder**](docs/ServerStatusApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_status_server_status_health_responder) | **GET** /api/serverstatus/health | 
*ServerStatusApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_status_server_status_responder**](docs/ServerStatusApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_status_server_status_responder) | **GET** /api/serverstatus | 
*ServerStatusApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_status_system_garbage_collect_responder**](docs/ServerStatusApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_status_system_garbage_collect_responder) | **POST** /api/serverstatus/gc-collect | 
*ServerStatusApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_status_system_info_responder**](docs/ServerStatusApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_status_system_info_responder) | **GET** /api/serverstatus/system-info | 
*ServerStatusApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_status_system_report_responder**](docs/ServerStatusApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_status_system_report_responder) | **GET** /api/serverstatus/system-report | 
*ServerStatusApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_server_timezones_responder**](docs/ServerStatusApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_server_timezones_responder) | **GET** /api/serverstatus/timezones | 
*SmtpConfigurationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_smtp_configuration_get_action**](docs/SmtpConfigurationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_smtp_configuration_get_action) | **GET** /api/smtpconfiguration | 
*SmtpConfigurationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_smtp_configuration_update_action**](docs/SmtpConfigurationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_smtp_configuration_update_action) | **PUT** /api/smtpconfiguration | 
*SmtpConfigurationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_smtp_is_configured_responder**](docs/SmtpConfigurationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_smtp_is_configured_responder) | **GET** /api/smtpconfiguration/isconfigured | 
*SpaceHomeApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_space_home_responder**](docs/SpaceHomeApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_space_home_responder) | **GET** /api/(?&lt;spaceId&gt;Spaces-\d+) | 
*SpacesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_create_space_responder**](docs/SpacesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_create_space_responder) | **POST** /api/spaces | 
*SpacesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_delete_space_responder**](docs/SpacesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_delete_space_responder) | **DELETE** /api/spaces/{id} | 
*SpacesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_modify_space_responder**](docs/SpacesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_modify_space_responder) | **PUT** /api/spaces/{id} | 
*SpacesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_space_logo_get_responder**](docs/SpacesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_space_logo_get_responder) | **GET** /api/spaces/{id}/logo | 
*SpacesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_space_logo_put_responder**](docs/SpacesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_space_logo_put_responder) | **PUT** /api/spaces/{id}/logo | 
*SpacesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_space_logo_put_responder_0**](docs/SpacesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_space_logo_put_responder_0) | **POST** /api/spaces/{id}/logo | 
*SpacesApi* | [**index_response_descriptor_spaces_space_space_resource**](docs/SpacesApi.md#index_response_descriptor_spaces_space_space_resource) | **GET** /api/spaces | Get a list of SpaceResources
*SpacesApi* | [**list_all_response_descriptor_spaces_space_space_resource**](docs/SpacesApi.md#list_all_response_descriptor_spaces_space_space_resource) | **GET** /api/spaces/all | Get a list of SpaceResources
*SpacesApi* | [**load_response_descriptor_spaces_space_space_resource**](docs/SpacesApi.md#load_response_descriptor_spaces_space_space_resource) | **GET** /api/spaces/{id} | Get a SpaceResource by ID
*SubscriptionApi* | [**create_response_descriptor_subscriptions_subscription_subscription_resource**](docs/SubscriptionApi.md#create_response_descriptor_subscriptions_subscription_subscription_resource) | **POST** /api/subscriptions | Create a SubscriptionResource
*SubscriptionApi* | [**create_response_descriptor_subscriptions_subscription_subscription_resource_spaces**](docs/SubscriptionApi.md#create_response_descriptor_subscriptions_subscription_subscription_resource_spaces) | **POST** /api/{baseSpaceId}/subscriptions | Create a SubscriptionResource
*SubscriptionApi* | [**delete_on_background_response_descriptor_subscriptions_subscription_subscription_resource**](docs/SubscriptionApi.md#delete_on_background_response_descriptor_subscriptions_subscription_subscription_resource) | **DELETE** /api/subscriptions/{id} | Delete a SubscriptionResource by ID
*SubscriptionApi* | [**delete_on_background_response_descriptor_subscriptions_subscription_subscription_resource_spaces**](docs/SubscriptionApi.md#delete_on_background_response_descriptor_subscriptions_subscription_subscription_resource_spaces) | **DELETE** /api/{baseSpaceId}/subscriptions/{id} | Delete a SubscriptionResource by ID
*SubscriptionApi* | [**index_response_descriptor_subscriptions_subscription_subscription_resource**](docs/SubscriptionApi.md#index_response_descriptor_subscriptions_subscription_subscription_resource) | **GET** /api/subscriptions | Get a list of SubscriptionResources
*SubscriptionApi* | [**index_response_descriptor_subscriptions_subscription_subscription_resource_spaces**](docs/SubscriptionApi.md#index_response_descriptor_subscriptions_subscription_subscription_resource_spaces) | **GET** /api/{baseSpaceId}/subscriptions | Get a list of SubscriptionResources
*SubscriptionApi* | [**list_all_response_descriptor_subscriptions_subscription_subscription_resource**](docs/SubscriptionApi.md#list_all_response_descriptor_subscriptions_subscription_subscription_resource) | **GET** /api/subscriptions/all | Get a list of SubscriptionResources
*SubscriptionApi* | [**list_all_response_descriptor_subscriptions_subscription_subscription_resource_spaces**](docs/SubscriptionApi.md#list_all_response_descriptor_subscriptions_subscription_subscription_resource_spaces) | **GET** /api/{baseSpaceId}/subscriptions/all | Get a list of SubscriptionResources
*SubscriptionApi* | [**load_response_descriptor_subscriptions_subscription_subscription_resource**](docs/SubscriptionApi.md#load_response_descriptor_subscriptions_subscription_subscription_resource) | **GET** /api/subscriptions/{id} | Get a SubscriptionResource by ID
*SubscriptionApi* | [**load_response_descriptor_subscriptions_subscription_subscription_resource_spaces**](docs/SubscriptionApi.md#load_response_descriptor_subscriptions_subscription_subscription_resource_spaces) | **GET** /api/{baseSpaceId}/subscriptions/{id} | Get a SubscriptionResource by ID
*SubscriptionApi* | [**modify_response_descriptor_subscriptions_subscription_subscription_resource**](docs/SubscriptionApi.md#modify_response_descriptor_subscriptions_subscription_subscription_resource) | **PUT** /api/subscriptions/{id} | Modify a SubscriptionResource by ID
*SubscriptionApi* | [**modify_response_descriptor_subscriptions_subscription_subscription_resource_spaces**](docs/SubscriptionApi.md#modify_response_descriptor_subscriptions_subscription_subscription_resource_spaces) | **PUT** /api/{baseSpaceId}/subscriptions/{id} | Modify a SubscriptionResource by ID
*TagSetsApi* | [**create_response_descriptor_tag_sets_tag_set_tag_set_resource**](docs/TagSetsApi.md#create_response_descriptor_tag_sets_tag_set_tag_set_resource) | **POST** /api/tagsets | Create a TagSetResource
*TagSetsApi* | [**create_response_descriptor_tag_sets_tag_set_tag_set_resource_spaces**](docs/TagSetsApi.md#create_response_descriptor_tag_sets_tag_set_tag_set_resource_spaces) | **POST** /api/{baseSpaceId}/tagsets | Create a TagSetResource
*TagSetsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_sort_tag_sets_responder**](docs/TagSetsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_sort_tag_sets_responder) | **PUT** /api/tagsets/sortorder | 
*TagSetsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_sort_tag_sets_responder_spaces**](docs/TagSetsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_sort_tag_sets_responder_spaces) | **PUT** /api/{baseSpaceId}/tagsets/sortorder | 
*TagSetsApi* | [**delete_on_background_response_descriptor_tag_sets_tag_set_tag_set_resource**](docs/TagSetsApi.md#delete_on_background_response_descriptor_tag_sets_tag_set_tag_set_resource) | **DELETE** /api/tagsets/{id} | Delete a TagSetResource by ID
*TagSetsApi* | [**delete_on_background_response_descriptor_tag_sets_tag_set_tag_set_resource_spaces**](docs/TagSetsApi.md#delete_on_background_response_descriptor_tag_sets_tag_set_tag_set_resource_spaces) | **DELETE** /api/{baseSpaceId}/tagsets/{id} | Delete a TagSetResource by ID
*TagSetsApi* | [**index_response_descriptor_tag_sets_tag_set_tag_set_resource**](docs/TagSetsApi.md#index_response_descriptor_tag_sets_tag_set_tag_set_resource) | **GET** /api/tagsets | Get a list of TagSetResources
*TagSetsApi* | [**index_response_descriptor_tag_sets_tag_set_tag_set_resource_spaces**](docs/TagSetsApi.md#index_response_descriptor_tag_sets_tag_set_tag_set_resource_spaces) | **GET** /api/{baseSpaceId}/tagsets | Get a list of TagSetResources
*TagSetsApi* | [**list_all_response_descriptor_tag_sets_tag_set_tag_set_resource**](docs/TagSetsApi.md#list_all_response_descriptor_tag_sets_tag_set_tag_set_resource) | **GET** /api/tagsets/all | Get a list of TagSetResources
*TagSetsApi* | [**list_all_response_descriptor_tag_sets_tag_set_tag_set_resource_spaces**](docs/TagSetsApi.md#list_all_response_descriptor_tag_sets_tag_set_tag_set_resource_spaces) | **GET** /api/{baseSpaceId}/tagsets/all | Get a list of TagSetResources
*TagSetsApi* | [**load_response_descriptor_tag_sets_tag_set_tag_set_resource**](docs/TagSetsApi.md#load_response_descriptor_tag_sets_tag_set_tag_set_resource) | **GET** /api/tagsets/{id} | Get a TagSetResource by ID
*TagSetsApi* | [**load_response_descriptor_tag_sets_tag_set_tag_set_resource_spaces**](docs/TagSetsApi.md#load_response_descriptor_tag_sets_tag_set_tag_set_resource_spaces) | **GET** /api/{baseSpaceId}/tagsets/{id} | Get a TagSetResource by ID
*TagSetsApi* | [**modify_response_descriptor_tag_sets_tag_set_tag_set_resource**](docs/TagSetsApi.md#modify_response_descriptor_tag_sets_tag_set_tag_set_resource) | **PUT** /api/tagsets/{id} | Modify a TagSetResource by ID
*TagSetsApi* | [**modify_response_descriptor_tag_sets_tag_set_tag_set_resource_spaces**](docs/TagSetsApi.md#modify_response_descriptor_tag_sets_tag_set_tag_set_resource_spaces) | **PUT** /api/{baseSpaceId}/tagsets/{id} | Modify a TagSetResource by ID
*TasksApi* | [**create_response_descriptor_server_tasks_server_task_task_resource**](docs/TasksApi.md#create_response_descriptor_server_tasks_server_task_task_resource) | **POST** /api/tasks | Create a TaskResource
*TasksApi* | [**create_response_descriptor_server_tasks_server_task_task_resource_spaces**](docs/TasksApi.md#create_response_descriptor_server_tasks_server_task_task_resource_spaces) | **POST** /api/{baseSpaceId}/tasks | Create a TaskResource
*TasksApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_task_cancel_responder**](docs/TasksApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_task_cancel_responder) | **POST** /api/tasks/{id}/cancel | 
*TasksApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_task_cancel_responder_spaces**](docs/TasksApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_task_cancel_responder_spaces) | **POST** /api/{baseSpaceId}/tasks/{id}/cancel | 
*TasksApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_task_details_responder**](docs/TasksApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_task_details_responder) | **GET** /api/tasks/{id}/details | 
*TasksApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_task_details_responder_spaces**](docs/TasksApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_task_details_responder_spaces) | **GET** /api/{baseSpaceId}/tasks/{id}/details | 
*TasksApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_task_raw_responder**](docs/TasksApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_task_raw_responder) | **GET** /api/tasks/{id}/raw | 
*TasksApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_task_raw_responder_spaces**](docs/TasksApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_task_raw_responder_spaces) | **GET** /api/{baseSpaceId}/tasks/{id}/raw | 
*TasksApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_task_rerun_responder**](docs/TasksApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_task_rerun_responder) | **POST** /api/tasks/rerun/{id} | 
*TasksApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_task_rerun_responder_spaces**](docs/TasksApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_task_rerun_responder_spaces) | **POST** /api/{baseSpaceId}/tasks/rerun/{id} | 
*TasksApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_task_state_responder**](docs/TasksApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_task_state_responder) | **POST** /api/tasks/{id}/state | 
*TasksApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_task_state_responder_spaces**](docs/TasksApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_task_state_responder_spaces) | **POST** /api/{baseSpaceId}/tasks/{id}/state | 
*TasksApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_task_types_responder**](docs/TasksApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_task_types_responder) | **GET** /api/tasks/tasktypes | 
*TasksApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_task_types_responder_spaces**](docs/TasksApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_task_types_responder_spaces) | **GET** /api/{baseSpaceId}/tasks/tasktypes | 
*TasksApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_tasks_responder**](docs/TasksApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_tasks_responder) | **GET** /api/tasks | 
*TasksApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_tasks_responder_spaces**](docs/TasksApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_tasks_responder_spaces) | **GET** /api/{baseSpaceId}/tasks | 
*TasksApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_task_queued_behind_responder**](docs/TasksApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_task_queued_behind_responder) | **GET** /api/tasks/{id}/queued-behind | 
*TasksApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_task_queued_behind_responder_spaces**](docs/TasksApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_task_queued_behind_responder_spaces) | **GET** /api/{baseSpaceId}/tasks/{id}/queued-behind | 
*TasksApi* | [**load_response_descriptor_server_tasks_server_task_task_resource**](docs/TasksApi.md#load_response_descriptor_server_tasks_server_task_task_resource) | **GET** /api/tasks/{id} | Get a TaskResource by ID
*TasksApi* | [**load_response_descriptor_server_tasks_server_task_task_resource_spaces**](docs/TasksApi.md#load_response_descriptor_server_tasks_server_task_task_resource_spaces) | **GET** /api/{baseSpaceId}/tasks/{id} | Get a TaskResource by ID
*TeamsApi* | [**create_response_descriptor_users_team_team_resource**](docs/TeamsApi.md#create_response_descriptor_users_team_team_resource) | **POST** /api/teams | Create a TeamResource
*TeamsApi* | [**create_response_descriptor_users_team_team_resource_spaces**](docs/TeamsApi.md#create_response_descriptor_users_team_team_resource_spaces) | **POST** /api/{baseSpaceId}/teams | Create a TeamResource
*TeamsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_scoped_user_role_responder**](docs/TeamsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_scoped_user_role_responder) | **GET** /api/teams/{id}/scopeduserroles | 
*TeamsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_scoped_user_role_responder_spaces**](docs/TeamsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_scoped_user_role_responder_spaces) | **GET** /api/{baseSpaceId}/teams/{id}/scopeduserroles | 
*TeamsApi* | [**delete_on_background_response_descriptor_users_team_team_resource**](docs/TeamsApi.md#delete_on_background_response_descriptor_users_team_team_resource) | **DELETE** /api/teams/{id} | Delete a TeamResource by ID
*TeamsApi* | [**delete_on_background_response_descriptor_users_team_team_resource_spaces**](docs/TeamsApi.md#delete_on_background_response_descriptor_users_team_team_resource_spaces) | **DELETE** /api/{baseSpaceId}/teams/{id} | Delete a TeamResource by ID
*TeamsApi* | [**index_response_descriptor_users_team_team_resource**](docs/TeamsApi.md#index_response_descriptor_users_team_team_resource) | **GET** /api/teams | Get a list of TeamResources
*TeamsApi* | [**index_response_descriptor_users_team_team_resource_spaces**](docs/TeamsApi.md#index_response_descriptor_users_team_team_resource_spaces) | **GET** /api/{baseSpaceId}/teams | Get a list of TeamResources
*TeamsApi* | [**list_all_response_descriptor_users_team_team_resource**](docs/TeamsApi.md#list_all_response_descriptor_users_team_team_resource) | **GET** /api/teams/all | Get a list of TeamResources
*TeamsApi* | [**list_all_response_descriptor_users_team_team_resource_spaces**](docs/TeamsApi.md#list_all_response_descriptor_users_team_team_resource_spaces) | **GET** /api/{baseSpaceId}/teams/all | Get a list of TeamResources
*TeamsApi* | [**load_response_descriptor_users_team_team_resource**](docs/TeamsApi.md#load_response_descriptor_users_team_team_resource) | **GET** /api/teams/{id} | Get a TeamResource by ID
*TeamsApi* | [**load_response_descriptor_users_team_team_resource_spaces**](docs/TeamsApi.md#load_response_descriptor_users_team_team_resource_spaces) | **GET** /api/{baseSpaceId}/teams/{id} | Get a TeamResource by ID
*TeamsApi* | [**modify_response_descriptor_users_team_team_resource**](docs/TeamsApi.md#modify_response_descriptor_users_team_team_resource) | **PUT** /api/teams/{id} | Modify a TeamResource by ID
*TeamsApi* | [**modify_response_descriptor_users_team_team_resource_spaces**](docs/TeamsApi.md#modify_response_descriptor_users_team_team_resource_spaces) | **PUT** /api/{baseSpaceId}/teams/{id} | Modify a TeamResource by ID
*TenantVariablesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variables_all_responder**](docs/TenantVariablesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variables_all_responder) | **GET** /api/tenantvariables/all | 
*TenantVariablesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variables_all_responder_spaces**](docs/TenantVariablesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variables_all_responder_spaces) | **GET** /api/{baseSpaceId}/tenantvariables/all | 
*TenantsApi* | [**create_response_descriptor_tenants_tenant_tenant_resource**](docs/TenantsApi.md#create_response_descriptor_tenants_tenant_tenant_resource) | **POST** /api/tenants | Create a TenantResource
*TenantsApi* | [**create_response_descriptor_tenants_tenant_tenant_resource_spaces**](docs/TenantsApi.md#create_response_descriptor_tenants_tenant_tenant_resource_spaces) | **POST** /api/{baseSpaceId}/tenants | Create a TenantResource
*TenantsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_tenant_logo_get_responder**](docs/TenantsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_tenant_logo_get_responder) | **GET** /api/tenants/{id}/logo | 
*TenantsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_tenant_logo_get_responder_spaces**](docs/TenantsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_tenant_logo_get_responder_spaces) | **GET** /api/{baseSpaceId}/tenants/{id}/logo | 
*TenantsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_tenant_logo_put_responder**](docs/TenantsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_tenant_logo_put_responder) | **PUT** /api/tenants/{id}/logo | 
*TenantsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_tenant_logo_put_responder_0**](docs/TenantsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_tenant_logo_put_responder_0) | **POST** /api/tenants/{id}/logo | 
*TenantsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_tenant_logo_put_responder_spaces**](docs/TenantsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_tenant_logo_put_responder_spaces) | **PUT** /api/{baseSpaceId}/tenants/{id}/logo | 
*TenantsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_tenant_logo_put_responder_spaces_0**](docs/TenantsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_tenant_logo_put_responder_spaces_0) | **POST** /api/{baseSpaceId}/tenants/{id}/logo | 
*TenantsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_tenant_tag_test_action**](docs/TenantsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_tenant_tag_test_action) | **GET** /api/tenants/tag-test | 
*TenantsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_tenant_tag_test_action_spaces**](docs/TenantsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_tenant_tag_test_action_spaces) | **GET** /api/{baseSpaceId}/tenants/tag-test | 
*TenantsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variable_set_test_action**](docs/TenantsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variable_set_test_action) | **GET** /api/tenants/variableset-test | 
*TenantsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variable_set_test_action_spaces**](docs/TenantsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variable_set_test_action_spaces) | **GET** /api/{baseSpaceId}/tenants/variableset-test | 
*TenantsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variables_get_responder**](docs/TenantsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variables_get_responder) | **GET** /api/tenants/{id}/variables | 
*TenantsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variables_get_responder_spaces**](docs/TenantsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variables_get_responder_spaces) | **GET** /api/{baseSpaceId}/tenants/{id}/variables | 
*TenantsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variables_missing_action**](docs/TenantsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variables_missing_action) | **GET** /api/tenants/variables-missing | 
*TenantsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variables_missing_action_spaces**](docs/TenantsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variables_missing_action_spaces) | **GET** /api/{baseSpaceId}/tenants/variables-missing | 
*TenantsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variables_put_responder**](docs/TenantsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variables_put_responder) | **PUT** /api/tenants/{id}/variables | 
*TenantsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variables_put_responder_0**](docs/TenantsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variables_put_responder_0) | **POST** /api/tenants/{id}/variables | 
*TenantsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variables_put_responder_spaces**](docs/TenantsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variables_put_responder_spaces) | **PUT** /api/{baseSpaceId}/tenants/{id}/variables | 
*TenantsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variables_put_responder_spaces_0**](docs/TenantsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_tenant_variables_put_responder_spaces_0) | **POST** /api/{baseSpaceId}/tenants/{id}/variables | 
*TenantsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_tenants_configuration_get_action**](docs/TenantsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_tenants_configuration_get_action) | **GET** /api/tenants/status | 
*TenantsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_tenants_configuration_get_action_spaces**](docs/TenantsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_tenants_configuration_get_action_spaces) | **GET** /api/{baseSpaceId}/tenants/status | 
*TenantsApi* | [**delete_on_background_response_descriptor_tenants_tenant_tenant_resource**](docs/TenantsApi.md#delete_on_background_response_descriptor_tenants_tenant_tenant_resource) | **DELETE** /api/tenants/{id} | Delete a TenantResource by ID
*TenantsApi* | [**delete_on_background_response_descriptor_tenants_tenant_tenant_resource_spaces**](docs/TenantsApi.md#delete_on_background_response_descriptor_tenants_tenant_tenant_resource_spaces) | **DELETE** /api/{baseSpaceId}/tenants/{id} | Delete a TenantResource by ID
*TenantsApi* | [**index_response_descriptor_tenants_tenant_tenant_resource**](docs/TenantsApi.md#index_response_descriptor_tenants_tenant_tenant_resource) | **GET** /api/tenants | Get a list of TenantResources
*TenantsApi* | [**index_response_descriptor_tenants_tenant_tenant_resource_spaces**](docs/TenantsApi.md#index_response_descriptor_tenants_tenant_tenant_resource_spaces) | **GET** /api/{baseSpaceId}/tenants | Get a list of TenantResources
*TenantsApi* | [**list_all_response_descriptor_tenants_tenant_tenant_resource**](docs/TenantsApi.md#list_all_response_descriptor_tenants_tenant_tenant_resource) | **GET** /api/tenants/all | Get a list of TenantResources
*TenantsApi* | [**list_all_response_descriptor_tenants_tenant_tenant_resource_spaces**](docs/TenantsApi.md#list_all_response_descriptor_tenants_tenant_tenant_resource_spaces) | **GET** /api/{baseSpaceId}/tenants/all | Get a list of TenantResources
*TenantsApi* | [**load_response_descriptor_tenants_tenant_tenant_resource**](docs/TenantsApi.md#load_response_descriptor_tenants_tenant_tenant_resource) | **GET** /api/tenants/{id} | Get a TenantResource by ID
*TenantsApi* | [**load_response_descriptor_tenants_tenant_tenant_resource_spaces**](docs/TenantsApi.md#load_response_descriptor_tenants_tenant_tenant_resource_spaces) | **GET** /api/{baseSpaceId}/tenants/{id} | Get a TenantResource by ID
*TenantsApi* | [**modify_response_descriptor_tenants_tenant_tenant_resource**](docs/TenantsApi.md#modify_response_descriptor_tenants_tenant_tenant_resource) | **PUT** /api/tenants/{id} | Modify a TenantResource by ID
*TenantsApi* | [**modify_response_descriptor_tenants_tenant_tenant_resource_spaces**](docs/TenantsApi.md#modify_response_descriptor_tenants_tenant_tenant_resource_spaces) | **PUT** /api/{baseSpaceId}/tenants/{id} | Modify a TenantResource by ID
*UpgradeConfigurationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_upgrade_configuration_get_action**](docs/UpgradeConfigurationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_upgrade_configuration_get_action) | **GET** /api/upgradeconfiguration | 
*UpgradeConfigurationApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_upgrade_configuration_update_action**](docs/UpgradeConfigurationApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_upgrade_configuration_update_action) | **PUT** /api/upgradeconfiguration | 
*UserOnboardingApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_onboarding_onboarding_get_action**](docs/UserOnboardingApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_onboarding_onboarding_get_action) | **GET** /api/useronboarding | 
*UserOnboardingApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_onboarding_onboarding_get_action_spaces**](docs/UserOnboardingApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_onboarding_onboarding_get_action_spaces) | **GET** /api/{baseSpaceId}/useronboarding | 
*UserPermissionsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_users_user_get_permissions_action**](docs/UserPermissionsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_users_user_get_permissions_action) | **GET** /api/users/{id}/permissions | 
*UserPermissionsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_users_user_get_permissions_action_spaces**](docs/UserPermissionsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_users_user_get_permissions_action_spaces) | **GET** /api/{baseSpaceId}/users/{id}/permissions | 
*UserPermissionsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_users_user_get_permissions_configuration_action**](docs/UserPermissionsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_users_user_get_permissions_configuration_action) | **GET** /api/users/{id}/permissions/configuration | 
*UserPermissionsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_users_user_get_permissions_configuration_action_spaces**](docs/UserPermissionsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_users_user_get_permissions_configuration_action_spaces) | **GET** /api/{baseSpaceId}/users/{id}/permissions/configuration | 
*UserPermissionsApi* | [**file_response_descriptor_octopus_server_web_api_actions_users_user_get_permissions_export_action**](docs/UserPermissionsApi.md#file_response_descriptor_octopus_server_web_api_actions_users_user_get_permissions_export_action) | **GET** /api/users/{id}/permissions/export | 
*UserPermissionsApi* | [**file_response_descriptor_octopus_server_web_api_actions_users_user_get_permissions_export_action_spaces**](docs/UserPermissionsApi.md#file_response_descriptor_octopus_server_web_api_actions_users_user_get_permissions_export_action_spaces) | **GET** /api/{baseSpaceId}/users/{id}/permissions/export | 
*UserRolesApi* | [**create_response_descriptor_users_user_role_user_role_resource**](docs/UserRolesApi.md#create_response_descriptor_users_user_role_user_role_resource) | **POST** /api/userroles | Create a UserRoleResource
*UserRolesApi* | [**delete_on_background_response_descriptor_users_user_role_user_role_resource**](docs/UserRolesApi.md#delete_on_background_response_descriptor_users_user_role_user_role_resource) | **DELETE** /api/userroles/{id} | Delete a UserRoleResource by ID
*UserRolesApi* | [**index_response_descriptor_users_user_role_user_role_resource**](docs/UserRolesApi.md#index_response_descriptor_users_user_role_user_role_resource) | **GET** /api/userroles | Get a list of UserRoleResources
*UserRolesApi* | [**list_all_response_descriptor_users_user_role_user_role_resource**](docs/UserRolesApi.md#list_all_response_descriptor_users_user_role_user_role_resource) | **GET** /api/userroles/all | Get a list of UserRoleResources
*UserRolesApi* | [**load_response_descriptor_users_user_role_user_role_resource**](docs/UserRolesApi.md#load_response_descriptor_users_user_role_user_role_resource) | **GET** /api/userroles/{id} | Get a UserRoleResource by ID
*UserRolesApi* | [**modify_response_descriptor_users_user_role_user_role_resource**](docs/UserRolesApi.md#modify_response_descriptor_users_user_role_user_role_resource) | **PUT** /api/userroles/{id} | Modify a UserRoleResource by ID
*UserTeamsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_users_user_get_teams_action**](docs/UserTeamsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_users_user_get_teams_action) | **GET** /api/users/{id}/teams | 
*UserTeamsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_users_user_get_teams_action_spaces**](docs/UserTeamsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_users_user_get_teams_action_spaces) | **GET** /api/{baseSpaceId}/users/{id}/teams | 
*UsersApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_users_user_authentication_responder**](docs/UsersApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_users_user_authentication_responder) | **GET** /api/users/authentication/{userId?} | 
*UsersApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_users_user_create_action**](docs/UsersApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_users_user_create_action) | **POST** /api/users | 
*UsersApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_users_user_external_search_action**](docs/UsersApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_users_user_external_search_action) | **GET** /api/users/external-search | 
*UsersApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_users_user_get_current_action**](docs/UsersApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_users_user_get_current_action) | **GET** /api/users/me | 
*UsersApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_users_user_get_spaces_action**](docs/UsersApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_users_user_get_spaces_action) | **GET** /api/users/{id}/spaces | 
*UsersApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_users_user_identity_metadata_action**](docs/UsersApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_users_user_identity_metadata_action) | **GET** /api/users/identity-metadata | 
*UsersApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_users_user_login_action**](docs/UsersApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_users_user_login_action) | **POST** /api/users/login | 
*UsersApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_users_user_logout_action**](docs/UsersApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_users_user_logout_action) | **POST** /api/users/logout | 
*UsersApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_users_user_register_action**](docs/UsersApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_users_user_register_action) | **POST** /api/users/register | 
*UsersApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_users_user_update_action**](docs/UsersApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_users_user_update_action) | **PUT** /api/users/{id} | 
*UsersApi* | [**delete_on_background_response_descriptor_users_user_user_resource**](docs/UsersApi.md#delete_on_background_response_descriptor_users_user_user_resource) | **DELETE** /api/users/{id} | Delete a UserResource by ID
*UsersApi* | [**index_response_descriptor_users_user_user_resource**](docs/UsersApi.md#index_response_descriptor_users_user_user_resource) | **GET** /api/users | Get a list of UserResources
*UsersApi* | [**list_all_response_descriptor_users_user_user_resource**](docs/UsersApi.md#list_all_response_descriptor_users_user_user_resource) | **GET** /api/users/all | Get a list of UserResources
*UsersApi* | [**load_response_descriptor_users_user_user_resource**](docs/UsersApi.md#load_response_descriptor_users_user_user_resource) | **GET** /api/users/{id} | Get a UserResource by ID
*VariablesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_check_for_non_printable_chars_action**](docs/VariablesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_check_for_non_printable_chars_action) | **POST** /api/variables/nonPrintableChars | 
*VariablesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_check_for_non_printable_chars_action_spaces**](docs/VariablesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_check_for_non_printable_chars_action_spaces) | **POST** /api/{baseSpaceId}/variables/nonPrintableChars | 
*VariablesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_variable_names_list_action**](docs/VariablesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_variable_names_list_action) | **GET** /api/variables/names | 
*VariablesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_variable_names_list_action_spaces**](docs/VariablesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_variable_names_list_action_spaces) | **GET** /api/{baseSpaceId}/variables/names | 
*VariablesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_variable_preview_list_action**](docs/VariablesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_variable_preview_list_action) | **GET** /api/variables/preview | 
*VariablesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_variable_preview_list_action_spaces**](docs/VariablesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_variable_preview_list_action_spaces) | **GET** /api/{baseSpaceId}/variables/preview | 
*VariablesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_variable_set_update_action**](docs/VariablesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_variable_set_update_action) | **PUT** /api/variables/{id} | 
*VariablesApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_variable_set_update_action_spaces**](docs/VariablesApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_variable_set_update_action_spaces) | **PUT** /api/{baseSpaceId}/variables/{id} | 
*VariablesApi* | [**list_all_response_descriptor_variables_variable_set_variable_set_resource**](docs/VariablesApi.md#list_all_response_descriptor_variables_variable_set_variable_set_resource) | **GET** /api/variables/all | Get a list of VariableSetResources
*VariablesApi* | [**list_all_response_descriptor_variables_variable_set_variable_set_resource_spaces**](docs/VariablesApi.md#list_all_response_descriptor_variables_variable_set_variable_set_resource_spaces) | **GET** /api/{baseSpaceId}/variables/all | Get a list of VariableSetResources
*VariablesApi* | [**load_response_descriptor_variables_variable_set_variable_set_resource**](docs/VariablesApi.md#load_response_descriptor_variables_variable_set_variable_set_resource) | **GET** /api/variables/{id} | Get a VariableSetResource by ID
*VariablesApi* | [**load_response_descriptor_variables_variable_set_variable_set_resource_spaces**](docs/VariablesApi.md#load_response_descriptor_variables_variable_set_variable_set_resource_spaces) | **GET** /api/{baseSpaceId}/variables/{id} | Get a VariableSetResource by ID
*WorkerPoolsApi* | [**create_response_descriptor_worker_pools_worker_pool_worker_pool_resource**](docs/WorkerPoolsApi.md#create_response_descriptor_worker_pools_worker_pool_worker_pool_resource) | **POST** /api/workerpools | Create a WorkerPoolResource
*WorkerPoolsApi* | [**create_response_descriptor_worker_pools_worker_pool_worker_pool_resource_spaces**](docs/WorkerPoolsApi.md#create_response_descriptor_worker_pools_worker_pool_worker_pool_resource_spaces) | **POST** /api/{baseSpaceId}/workerpools | Create a WorkerPoolResource
*WorkerPoolsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_sort_worker_pools_responder**](docs/WorkerPoolsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_sort_worker_pools_responder) | **PUT** /api/workerpools/sortorder | 
*WorkerPoolsApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_sort_worker_pools_responder_spaces**](docs/WorkerPoolsApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_sort_worker_pools_responder_spaces) | **PUT** /api/{baseSpaceId}/workerpools/sortorder | 
*WorkerPoolsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_infrastructure_summary_worker_pools_summary_responder**](docs/WorkerPoolsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_infrastructure_summary_worker_pools_summary_responder) | **GET** /api/workerpools/summary | 
*WorkerPoolsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_infrastructure_summary_worker_pools_summary_responder_spaces**](docs/WorkerPoolsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_infrastructure_summary_worker_pools_summary_responder_spaces) | **GET** /api/{baseSpaceId}/workerpools/summary | 
*WorkerPoolsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_worker_pools_workers_responder**](docs/WorkerPoolsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_worker_pools_workers_responder) | **GET** /api/workerpools/{id}/workers | 
*WorkerPoolsApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_worker_pools_workers_responder_spaces**](docs/WorkerPoolsApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_worker_pools_workers_responder_spaces) | **GET** /api/{baseSpaceId}/workerpools/{id}/workers | 
*WorkerPoolsApi* | [**delete_on_background_response_descriptor_worker_pools_worker_pool_worker_pool_resource**](docs/WorkerPoolsApi.md#delete_on_background_response_descriptor_worker_pools_worker_pool_worker_pool_resource) | **DELETE** /api/workerpools/{id} | Delete a WorkerPoolResource by ID
*WorkerPoolsApi* | [**delete_on_background_response_descriptor_worker_pools_worker_pool_worker_pool_resource_spaces**](docs/WorkerPoolsApi.md#delete_on_background_response_descriptor_worker_pools_worker_pool_worker_pool_resource_spaces) | **DELETE** /api/{baseSpaceId}/workerpools/{id} | Delete a WorkerPoolResource by ID
*WorkerPoolsApi* | [**index_response_descriptor_worker_pools_worker_pool_worker_pool_resource**](docs/WorkerPoolsApi.md#index_response_descriptor_worker_pools_worker_pool_worker_pool_resource) | **GET** /api/workerpools | Get a list of WorkerPoolResources
*WorkerPoolsApi* | [**index_response_descriptor_worker_pools_worker_pool_worker_pool_resource_spaces**](docs/WorkerPoolsApi.md#index_response_descriptor_worker_pools_worker_pool_worker_pool_resource_spaces) | **GET** /api/{baseSpaceId}/workerpools | Get a list of WorkerPoolResources
*WorkerPoolsApi* | [**list_all_response_descriptor_worker_pools_worker_pool_worker_pool_resource**](docs/WorkerPoolsApi.md#list_all_response_descriptor_worker_pools_worker_pool_worker_pool_resource) | **GET** /api/workerpools/all | Get a list of WorkerPoolResources
*WorkerPoolsApi* | [**list_all_response_descriptor_worker_pools_worker_pool_worker_pool_resource_spaces**](docs/WorkerPoolsApi.md#list_all_response_descriptor_worker_pools_worker_pool_worker_pool_resource_spaces) | **GET** /api/{baseSpaceId}/workerpools/all | Get a list of WorkerPoolResources
*WorkerPoolsApi* | [**load_response_descriptor_worker_pools_worker_pool_worker_pool_resource**](docs/WorkerPoolsApi.md#load_response_descriptor_worker_pools_worker_pool_worker_pool_resource) | **GET** /api/workerpools/{id} | Get a WorkerPoolResource by ID
*WorkerPoolsApi* | [**load_response_descriptor_worker_pools_worker_pool_worker_pool_resource_spaces**](docs/WorkerPoolsApi.md#load_response_descriptor_worker_pools_worker_pool_worker_pool_resource_spaces) | **GET** /api/{baseSpaceId}/workerpools/{id} | Get a WorkerPoolResource by ID
*WorkerPoolsApi* | [**modify_response_descriptor_worker_pools_worker_pool_worker_pool_resource**](docs/WorkerPoolsApi.md#modify_response_descriptor_worker_pools_worker_pool_worker_pool_resource) | **PUT** /api/workerpools/{id} | Modify a WorkerPoolResource by ID
*WorkerPoolsApi* | [**modify_response_descriptor_worker_pools_worker_pool_worker_pool_resource_spaces**](docs/WorkerPoolsApi.md#modify_response_descriptor_worker_pools_worker_pool_worker_pool_resource_spaces) | **PUT** /api/{baseSpaceId}/workerpools/{id} | Modify a WorkerPoolResource by ID
*WorkersApi* | [**create_response_descriptor_machines_workers_worker_worker_resource**](docs/WorkersApi.md#create_response_descriptor_machines_workers_worker_worker_resource) | **POST** /api/workers | Create a WorkerResource
*WorkersApi* | [**create_response_descriptor_machines_workers_worker_worker_resource_spaces**](docs/WorkersApi.md#create_response_descriptor_machines_workers_worker_worker_resource_spaces) | **POST** /api/{baseSpaceId}/workers | Create a WorkerResource
*WorkersApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_discover_worker_responder**](docs/WorkersApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_discover_worker_responder) | **GET** /api/workers/discover | 
*WorkersApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_discover_worker_responder_spaces**](docs/WorkersApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_discover_worker_responder_spaces) | **GET** /api/{baseSpaceId}/workers/discover | 
*WorkersApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_worker_connection_status_responder**](docs/WorkersApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_worker_connection_status_responder) | **GET** /api/workers/{id}/connection | 
*WorkersApi* | [**custom_action_response_descriptor_octopus_server_web_api_actions_worker_connection_status_responder_spaces**](docs/WorkersApi.md#custom_action_response_descriptor_octopus_server_web_api_actions_worker_connection_status_responder_spaces) | **GET** /api/{baseSpaceId}/workers/{id}/connection | 
*WorkersApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_worker_responder**](docs/WorkersApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_worker_responder) | **GET** /api/workers | 
*WorkersApi* | [**custom_query_response_descriptor_octopus_server_web_api_actions_list_worker_responder_spaces**](docs/WorkersApi.md#custom_query_response_descriptor_octopus_server_web_api_actions_list_worker_responder_spaces) | **GET** /api/{baseSpaceId}/workers | 
*WorkersApi* | [**delete_on_background_response_descriptor_machines_workers_worker_worker_resource**](docs/WorkersApi.md#delete_on_background_response_descriptor_machines_workers_worker_worker_resource) | **DELETE** /api/workers/{id} | Delete a WorkerResource by ID
*WorkersApi* | [**delete_on_background_response_descriptor_machines_workers_worker_worker_resource_spaces**](docs/WorkersApi.md#delete_on_background_response_descriptor_machines_workers_worker_worker_resource_spaces) | **DELETE** /api/{baseSpaceId}/workers/{id} | Delete a WorkerResource by ID
*WorkersApi* | [**list_all_response_descriptor_machines_workers_worker_worker_resource**](docs/WorkersApi.md#list_all_response_descriptor_machines_workers_worker_worker_resource) | **GET** /api/workers/all | Get a list of WorkerResources
*WorkersApi* | [**list_all_response_descriptor_machines_workers_worker_worker_resource_spaces**](docs/WorkersApi.md#list_all_response_descriptor_machines_workers_worker_worker_resource_spaces) | **GET** /api/{baseSpaceId}/workers/all | Get a list of WorkerResources
*WorkersApi* | [**load_response_descriptor_machines_workers_worker_worker_resource**](docs/WorkersApi.md#load_response_descriptor_machines_workers_worker_worker_resource) | **GET** /api/workers/{id} | Get a WorkerResource by ID
*WorkersApi* | [**load_response_descriptor_machines_workers_worker_worker_resource_spaces**](docs/WorkersApi.md#load_response_descriptor_machines_workers_worker_worker_resource_spaces) | **GET** /api/{baseSpaceId}/workers/{id} | Get a WorkerResource by ID
*WorkersApi* | [**modify_response_descriptor_machines_workers_worker_worker_resource**](docs/WorkersApi.md#modify_response_descriptor_machines_workers_worker_worker_resource) | **PUT** /api/workers/{id} | Modify a WorkerResource by ID
*WorkersApi* | [**modify_response_descriptor_machines_workers_worker_worker_resource_spaces**](docs/WorkersApi.md#modify_response_descriptor_machines_workers_worker_worker_resource_spaces) | **PUT** /api/{baseSpaceId}/workers/{id} | Modify a WorkerResource by ID


## Documentation For Models

 - [AccountResource](docs/AccountResource.md)
 - [AccountUsageResource](docs/AccountUsageResource.md)
 - [ActionTemplateCategoryResource](docs/ActionTemplateCategoryResource.md)
 - [ActionTemplateParameterResource](docs/ActionTemplateParameterResource.md)
 - [ActionTemplateResource](docs/ActionTemplateResource.md)
 - [ActionTemplateSearchResource](docs/ActionTemplateSearchResource.md)
 - [ActionTemplateUsageResource](docs/ActionTemplateUsageResource.md)
 - [ActionUpdateRemovedPackageUsage](docs/ActionUpdateRemovedPackageUsage.md)
 - [ActionUpdateResultResource](docs/ActionUpdateResultResource.md)
 - [ActivityLogElement](docs/ActivityLogElement.md)
 - [ActivityLogEntry](docs/ActivityLogEntry.md)
 - [ActivityLogTreeNode](docs/ActivityLogTreeNode.md)
 - [ApiKeyResource](docs/ApiKeyResource.md)
 - [ArtifactResource](docs/ArtifactResource.md)
 - [AuthenticationProviderElement](docs/AuthenticationProviderElement.md)
 - [AuthenticationProviderThatSupportsGroups](docs/AuthenticationProviderThatSupportsGroups.md)
 - [AuthenticationResource](docs/AuthenticationResource.md)
 - [AutoDeployReleaseOverrideResource](docs/AutoDeployReleaseOverrideResource.md)
 - [AzureEnvironmentResource](docs/AzureEnvironmentResource.md)
 - [AzureResourceGroupResource](docs/AzureResourceGroupResource.md)
 - [AzureStorageAccountResource](docs/AzureStorageAccountResource.md)
 - [AzureWebSiteResourceAzureWebSitesListAction](docs/AzureWebSiteResourceAzureWebSitesListAction.md)
 - [AzureWebSiteSlotResource](docs/AzureWebSiteSlotResource.md)
 - [BuiltInFeedStatsResource](docs/BuiltInFeedStatsResource.md)
 - [CertificateConfigurationResource](docs/CertificateConfigurationResource.md)
 - [CertificateResource](docs/CertificateResource.md)
 - [CertificateUsageResource](docs/CertificateUsageResource.md)
 - [ChannelResource](docs/ChannelResource.md)
 - [ChannelVersionRuleResource](docs/ChannelVersionRuleResource.md)
 - [CloudTemplateMetadata](docs/CloudTemplateMetadata.md)
 - [CommitDetails](docs/CommitDetails.md)
 - [CommunityActionTemplateResource](docs/CommunityActionTemplateResource.md)
 - [ConfigurationSectionMetadata](docs/ConfigurationSectionMetadata.md)
 - [Control](docs/Control.md)
 - [DashboardConfigurationResource](docs/DashboardConfigurationResource.md)
 - [DashboardEnvironmentResource](docs/DashboardEnvironmentResource.md)
 - [DashboardItemResource](docs/DashboardItemResource.md)
 - [DashboardProjectGroupResource](docs/DashboardProjectGroupResource.md)
 - [DashboardProjectResource](docs/DashboardProjectResource.md)
 - [DashboardResource](docs/DashboardResource.md)
 - [DashboardTenantResource](docs/DashboardTenantResource.md)
 - [DefectResource](docs/DefectResource.md)
 - [DeploymentActionPackageResource](docs/DeploymentActionPackageResource.md)
 - [DeploymentActionResource](docs/DeploymentActionResource.md)
 - [DeploymentEnvironmentSettingsMetadata](docs/DeploymentEnvironmentSettingsMetadata.md)
 - [DeploymentPreviewResource](docs/DeploymentPreviewResource.md)
 - [DeploymentProcessResource](docs/DeploymentProcessResource.md)
 - [DeploymentPromomotionTenant](docs/DeploymentPromomotionTenant.md)
 - [DeploymentPromotionTarget](docs/DeploymentPromotionTarget.md)
 - [DeploymentResource](docs/DeploymentResource.md)
 - [DeploymentStepResource](docs/DeploymentStepResource.md)
 - [DeploymentTargetResource](docs/DeploymentTargetResource.md)
 - [DeploymentTemplateResource](docs/DeploymentTemplateResource.md)
 - [DeploymentTemplateStep](docs/DeploymentTemplateStep.md)
 - [DisplayInfo](docs/DisplayInfo.md)
 - [DocumentTypeDocument](docs/DocumentTypeDocument.md)
 - [EndpointResource](docs/EndpointResource.md)
 - [EnvironmentResource](docs/EnvironmentResource.md)
 - [EventAgentResource](docs/EventAgentResource.md)
 - [EventCategoryResource](docs/EventCategoryResource.md)
 - [EventGroupResource](docs/EventGroupResource.md)
 - [EventNotificationSubscription](docs/EventNotificationSubscription.md)
 - [EventNotificationSubscriptionFilter](docs/EventNotificationSubscriptionFilter.md)
 - [EventReference](docs/EventReference.md)
 - [EventResource](docs/EventResource.md)
 - [ExtensionSettingsValues](docs/ExtensionSettingsValues.md)
 - [ExtensionsInfoResource](docs/ExtensionsInfoResource.md)
 - [FeaturesConfigurationResource](docs/FeaturesConfigurationResource.md)
 - [FeedResource](docs/FeedResource.md)
 - [Form](docs/Form.md)
 - [FormElement](docs/FormElement.md)
 - [IdentityClaimResource](docs/IdentityClaimResource.md)
 - [IdentityResource](docs/IdentityResource.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InterruptionResource](docs/InterruptionResource.md)
 - [InvitationResource](docs/InvitationResource.md)
 - [Library](docs/Library.md)
 - [LibraryVariableSetProjectUsage](docs/LibraryVariableSetProjectUsage.md)
 - [LibraryVariableSetReleaseUsageEntry](docs/LibraryVariableSetReleaseUsageEntry.md)
 - [LibraryVariableSetResource](docs/LibraryVariableSetResource.md)
 - [LibraryVariableSetUsageEntry](docs/LibraryVariableSetUsageEntry.md)
 - [LibraryVariableSetUsageResource](docs/LibraryVariableSetUsageResource.md)
 - [LicenseLimitStatusResource](docs/LicenseLimitStatusResource.md)
 - [LicenseMessageResource](docs/LicenseMessageResource.md)
 - [LicenseResource](docs/LicenseResource.md)
 - [LicenseStatusResource](docs/LicenseStatusResource.md)
 - [LifecycleProgressionResource](docs/LifecycleProgressionResource.md)
 - [LifecycleResource](docs/LifecycleResource.md)
 - [ListApiMetadata](docs/ListApiMetadata.md)
 - [LoginInitiatedResource](docs/LoginInitiatedResource.md)
 - [MachineCleanupPolicy](docs/MachineCleanupPolicy.md)
 - [MachineConnectionStatus](docs/MachineConnectionStatus.md)
 - [MachineConnectivityPolicy](docs/MachineConnectivityPolicy.md)
 - [MachineDeploymentPreview](docs/MachineDeploymentPreview.md)
 - [MachineHealthCheckPolicy](docs/MachineHealthCheckPolicy.md)
 - [MachinePolicyResource](docs/MachinePolicyResource.md)
 - [MachineResource](docs/MachineResource.md)
 - [MachineScriptPolicy](docs/MachineScriptPolicy.md)
 - [MachineUpdatePolicy](docs/MachineUpdatePolicy.md)
 - [MaintenanceConfigurationResource](docs/MaintenanceConfigurationResource.md)
 - [Metadata](docs/Metadata.md)
 - [MigrationImportResource](docs/MigrationImportResource.md)
 - [MigrationPartialExportResource](docs/MigrationPartialExportResource.md)
 - [MultiTenancyStatusResource](docs/MultiTenancyStatusResource.md)
 - [NamedReferenceItem](docs/NamedReferenceItem.md)
 - [NumericReportData](docs/NumericReportData.md)
 - [NumericReportSeries](docs/NumericReportSeries.md)
 - [OctopusPackageMetadataMappedResource](docs/OctopusPackageMetadataMappedResource.md)
 - [OctopusServerNodeDetailsResource](docs/OctopusServerNodeDetailsResource.md)
 - [OctopusServerNodeResource](docs/OctopusServerNodeResource.md)
 - [OnboardingResource](docs/OnboardingResource.md)
 - [OnboardingTaskResource](docs/OnboardingTaskResource.md)
 - [OptionsMetadata](docs/OptionsMetadata.md)
 - [PackageBuildMetadata](docs/PackageBuildMetadata.md)
 - [PackageDescriptionResource](docs/PackageDescriptionResource.md)
 - [PackageFromBuiltInFeedResource](docs/PackageFromBuiltInFeedResource.md)
 - [PackageNote](docs/PackageNote.md)
 - [PackageNoteListResource](docs/PackageNoteListResource.md)
 - [PackageNotesResult](docs/PackageNotesResult.md)
 - [PackageReference](docs/PackageReference.md)
 - [PackageResource](docs/PackageResource.md)
 - [PackageSignatureResource](docs/PackageSignatureResource.md)
 - [PackageVersionResource](docs/PackageVersionResource.md)
 - [PerformanceConfigurationResource](docs/PerformanceConfigurationResource.md)
 - [PermissionDescription](docs/PermissionDescription.md)
 - [PhaseDeploymentResource](docs/PhaseDeploymentResource.md)
 - [PhaseProgressionResource](docs/PhaseProgressionResource.md)
 - [PhaseResource](docs/PhaseResource.md)
 - [ProgressionResource](docs/ProgressionResource.md)
 - [Project](docs/Project.md)
 - [ProjectConnectivityPolicy](docs/ProjectConnectivityPolicy.md)
 - [ProjectGroupResource](docs/ProjectGroupResource.md)
 - [ProjectResource](docs/ProjectResource.md)
 - [ProjectSettingsMetadata](docs/ProjectSettingsMetadata.md)
 - [ProjectTriggerResource](docs/ProjectTriggerResource.md)
 - [ProjectVariableSetUsage](docs/ProjectVariableSetUsage.md)
 - [ProjectedTeamReferenceDataItem](docs/ProjectedTeamReferenceDataItem.md)
 - [PropertyApplicability](docs/PropertyApplicability.md)
 - [PropertyMetadata](docs/PropertyMetadata.md)
 - [PropertyValueResource](docs/PropertyValueResource.md)
 - [ProxyResource](docs/ProxyResource.md)
 - [ReferenceDataItem](docs/ReferenceDataItem.md)
 - [ReleaseChanges](docs/ReleaseChanges.md)
 - [ReleaseCreationStrategyResource](docs/ReleaseCreationStrategyResource.md)
 - [ReleasePackageMetadataResource](docs/ReleasePackageMetadataResource.md)
 - [ReleaseProgressionResource](docs/ReleaseProgressionResource.md)
 - [ReleaseResource](docs/ReleaseResource.md)
 - [ReleaseTemplatePackage](docs/ReleaseTemplatePackage.md)
 - [ReleaseTemplateResource](docs/ReleaseTemplateResource.md)
 - [ReleaseUsage](docs/ReleaseUsage.md)
 - [ReleaseUsageEntry](docs/ReleaseUsageEntry.md)
 - [ReportDeploymentCountOverTimeResource](docs/ReportDeploymentCountOverTimeResource.md)
 - [ResourceCollectionAccountResource](docs/ResourceCollectionAccountResource.md)
 - [ResourceCollectionActionTemplateResource](docs/ResourceCollectionActionTemplateResource.md)
 - [ResourceCollectionApiKeyResource](docs/ResourceCollectionApiKeyResource.md)
 - [ResourceCollectionArtifactResource](docs/ResourceCollectionArtifactResource.md)
 - [ResourceCollectionCertificateConfigurationResource](docs/ResourceCollectionCertificateConfigurationResource.md)
 - [ResourceCollectionCertificateResource](docs/ResourceCollectionCertificateResource.md)
 - [ResourceCollectionChannelResource](docs/ResourceCollectionChannelResource.md)
 - [ResourceCollectionCommunityActionTemplateResource](docs/ResourceCollectionCommunityActionTemplateResource.md)
 - [ResourceCollectionConfigurationSectionMetadata](docs/ResourceCollectionConfigurationSectionMetadata.md)
 - [ResourceCollectionDefectResource](docs/ResourceCollectionDefectResource.md)
 - [ResourceCollectionDeploymentProcessResource](docs/ResourceCollectionDeploymentProcessResource.md)
 - [ResourceCollectionDeploymentResource](docs/ResourceCollectionDeploymentResource.md)
 - [ResourceCollectionDeploymentTargetResource](docs/ResourceCollectionDeploymentTargetResource.md)
 - [ResourceCollectionEnvironmentResource](docs/ResourceCollectionEnvironmentResource.md)
 - [ResourceCollectionFeedResource](docs/ResourceCollectionFeedResource.md)
 - [ResourceCollectionInterruptionResource](docs/ResourceCollectionInterruptionResource.md)
 - [ResourceCollectionLibraryVariableSetResource](docs/ResourceCollectionLibraryVariableSetResource.md)
 - [ResourceCollectionLifecycleResource](docs/ResourceCollectionLifecycleResource.md)
 - [ResourceCollectionMachinePolicyResource](docs/ResourceCollectionMachinePolicyResource.md)
 - [ResourceCollectionOctopusServerNodeResource](docs/ResourceCollectionOctopusServerNodeResource.md)
 - [ResourceCollectionPackageDescriptionResource](docs/ResourceCollectionPackageDescriptionResource.md)
 - [ResourceCollectionPackageResource](docs/ResourceCollectionPackageResource.md)
 - [ResourceCollectionPackageVersionResource](docs/ResourceCollectionPackageVersionResource.md)
 - [ResourceCollectionProjectGroupResource](docs/ResourceCollectionProjectGroupResource.md)
 - [ResourceCollectionProjectResource](docs/ResourceCollectionProjectResource.md)
 - [ResourceCollectionProjectTriggerResource](docs/ResourceCollectionProjectTriggerResource.md)
 - [ResourceCollectionProxyResource](docs/ResourceCollectionProxyResource.md)
 - [ResourceCollectionReleaseResource](docs/ResourceCollectionReleaseResource.md)
 - [ResourceCollectionScopedUserRoleResource](docs/ResourceCollectionScopedUserRoleResource.md)
 - [ResourceCollectionSpaceResource](docs/ResourceCollectionSpaceResource.md)
 - [ResourceCollectionSubscriptionResource](docs/ResourceCollectionSubscriptionResource.md)
 - [ResourceCollectionTagSetResource](docs/ResourceCollectionTagSetResource.md)
 - [ResourceCollectionTaskResource](docs/ResourceCollectionTaskResource.md)
 - [ResourceCollectionTeamResource](docs/ResourceCollectionTeamResource.md)
 - [ResourceCollectionTenantResource](docs/ResourceCollectionTenantResource.md)
 - [ResourceCollectionUserResource](docs/ResourceCollectionUserResource.md)
 - [ResourceCollectionUserRoleResource](docs/ResourceCollectionUserRoleResource.md)
 - [ResourceCollectionWorkerPoolResource](docs/ResourceCollectionWorkerPoolResource.md)
 - [ResourceCollectionWorkerResource](docs/ResourceCollectionWorkerResource.md)
 - [RetentionPeriod](docs/RetentionPeriod.md)
 - [RootResource](docs/RootResource.md)
 - [ScheduledTaskDetailsResource](docs/ScheduledTaskDetailsResource.md)
 - [ScheduledTaskStatusResource](docs/ScheduledTaskStatusResource.md)
 - [SchedulerStatusResource](docs/SchedulerStatusResource.md)
 - [ScopedUserRoleResource](docs/ScopedUserRoleResource.md)
 - [SelectedPackage](docs/SelectedPackage.md)
 - [SensitiveValue](docs/SensitiveValue.md)
 - [ServerConfigurationResource](docs/ServerConfigurationResource.md)
 - [ServerConfigurationSettingsResource](docs/ServerConfigurationSettingsResource.md)
 - [ServerConfigurationValueResource](docs/ServerConfigurationValueResource.md)
 - [ServerStatusHealthResource](docs/ServerStatusHealthResource.md)
 - [ServerTimezoneResource](docs/ServerTimezoneResource.md)
 - [SmtpIsConfiguredResource](docs/SmtpIsConfiguredResource.md)
 - [SpaceResource](docs/SpaceResource.md)
 - [SpaceRootResource](docs/SpaceRootResource.md)
 - [StepUsage](docs/StepUsage.md)
 - [StepUsageEntry](docs/StepUsageEntry.md)
 - [SubscriptionResource](docs/SubscriptionResource.md)
 - [TagResource](docs/TagResource.md)
 - [TagSetResource](docs/TagSetResource.md)
 - [TargetUsageEntry](docs/TargetUsageEntry.md)
 - [TaskDetailsResource](docs/TaskDetailsResource.md)
 - [TaskProgress](docs/TaskProgress.md)
 - [TaskResource](docs/TaskResource.md)
 - [TaskTypeResource](docs/TaskTypeResource.md)
 - [TeamNameResource](docs/TeamNameResource.md)
 - [TeamResource](docs/TeamResource.md)
 - [TenantResource](docs/TenantResource.md)
 - [TenantVariableResource](docs/TenantVariableResource.md)
 - [TriggerActionResource](docs/TriggerActionResource.md)
 - [TriggerFilterResource](docs/TriggerFilterResource.md)
 - [TypeMetadata](docs/TypeMetadata.md)
 - [UserAuthenticationResource](docs/UserAuthenticationResource.md)
 - [UserPermissionRestriction](docs/UserPermissionRestriction.md)
 - [UserPermissionSetResource](docs/UserPermissionSetResource.md)
 - [UserPermissionSetResourceSpacePermissions](docs/UserPermissionSetResourceSpacePermissions.md)
 - [UserResource](docs/UserResource.md)
 - [UserRoleResource](docs/UserRoleResource.md)
 - [VariablePromptOptions](docs/VariablePromptOptions.md)
 - [VariableResource](docs/VariableResource.md)
 - [VariableResourceScope](docs/VariableResourceScope.md)
 - [VariableScopeValues](docs/VariableScopeValues.md)
 - [VariableSetResource](docs/VariableSetResource.md)
 - [VariablesScopedToEnvironmentResponse](docs/VariablesScopedToEnvironmentResponse.md)
 - [VersioningStrategyResource](docs/VersioningStrategyResource.md)
 - [WorkItemLink](docs/WorkItemLink.md)
 - [WorkerPoolResource](docs/WorkerPoolResource.md)
 - [WorkerResource](docs/WorkerResource.md)
 - [X509Certificate](docs/X509Certificate.md)


## Documentation For Authorization


## APIKeyHeader

- **Type**: API key
- **API key parameter name**: X-Octopus-ApiKey
- **Location**: HTTP header

## APIKeyQuery

- **Type**: API key
- **API key parameter name**: ApiKey
- **Location**: URL query string

## NugetApiKeyHeader

- **Type**: API key
- **API key parameter name**: X-NuGet-ApiKey
- **Location**: HTTP header


## Author



